@@ -13,12 +13,13 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6539 $
-## |  Last changed: $Date: 2022-08-30 15:17:09 +0200 (Tue, 30 Aug 2022) $
+## |  File version: $Revision: 7496 $
+## |  Last changed: $Date: 2023-12-15 10:42:15 +0100 (Fr, 15 Dez 2023) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
 #' @include f_core_constants.R
+#' @include f_core_assertions.R
 NULL
 
 #'
@@ -209,6 +210,27 @@ ParameterSet <- setRefClass("ParameterSet",
             .parameterFormatFunctions <<- list()
             .catLines <<- character(0)
         },
+        clone = function() {
+            paramNames <- names(.self$getRefClass()$fields())
+            plotSettingsEnabled <- ".plotSettings" %in% paramNames
+            designEnabled <- ".design" %in% paramNames
+            paramNames <- paramNames[!grepl("^\\.|^stages$", paramNames)]
+            args <- list()
+            if (designEnabled) {
+                args$design <- .self$.design
+            }
+            for (paramName in paramNames) {
+                if (.self$.getParameterType(paramName) == C_PARAM_USER_DEFINED) {
+                    args[[paramName]] <- .self[[paramName]]
+                }
+            }
+            what <- .getGeneratorFunctionName(.self)
+            result <- do.call(what = what, args = args)
+            if (plotSettingsEnabled && !is.null(.self$.plotSettings)) {
+                result$.plotSettings <- .self$.plotSettings$clone()
+            }
+            return(result)
+        },
         .toString = function(startWithUpperCase = FALSE) {
             s <- .formatCamelCase(.getClassName(.self))
             return(ifelse(startWithUpperCase, .firstCharacterToUpperCase(s), s))
@@ -661,9 +683,11 @@ ParameterSet <- setRefClass("ParameterSet",
             if (is.list(paramValueFormatted)) {
                 paramValueFormatted <- .listToString(paramValueFormatted)
             }
-            if (is.function(paramValue)) {
+            if (is.function(paramValue) || grepl("Function$", paramName)) {
                 paramValueFormatted <- ifelse(
-                    .getParameterType(paramName) == C_PARAM_USER_DEFINED, "user defined", "default"
+                    .getParameterType(paramName) == C_PARAM_USER_DEFINED,
+                    ifelse(.isCppCode(paramValueFormatted), "user defined (C++)", "user defined"),
+                    "default"
                 )
             }
             prefix <- ifelse(showParameterType, .showParameterType(paramName), "")
@@ -671,6 +695,7 @@ ParameterSet <- setRefClass("ParameterSet",
                 name = paramCaption,
                 n = .getNChar(), prefix = prefix
             )
+
             output <- paste(variableNameFormatted, paramValueFormatted, "\n")
             .cat(output, consoleOutputEnabled = consoleOutputEnabled)
             invisible(output)
@@ -710,7 +735,8 @@ ParameterSet <- setRefClass("ParameterSet",
                 niceColumnNamesEnabled = niceColumnNamesEnabled,
                 includeAllParameters = includeAllParameters,
                 handleParameterNamesAsToBeExcluded = handleParameterNamesAsToBeExcluded,
-                returnParametersAsCharacter = TRUE, tableColumnNames = tableColumnNames
+                returnParametersAsCharacter = TRUE,
+                tableColumnNames = tableColumnNames
             )
             result <- as.matrix(dataFrame)
             if (.isTrialDesignPlan(.self)) {
@@ -760,7 +786,6 @@ ParameterSet <- setRefClass("ParameterSet",
             return(n)
         },
         .getVariedParameter = function(parameterNames, numberOfVariants) {
-
             # search for user defined parameters
             for (parameterName in parameterNames) {
                 parameterValues <- .self[[parameterName]]
@@ -924,13 +949,16 @@ ParameterSet <- setRefClass("ParameterSet",
         parameterName,
         numberOfVariants,
         numberOfStages,
-        includeAllParameters) {
-    if (parameterSet$.getParameterType(parameterName) == C_PARAM_TYPE_UNKNOWN && 
+        includeAllParameters,
+        mandatoryParameterNames) {
+    if (parameterSet$.getParameterType(parameterName) == C_PARAM_TYPE_UNKNOWN &&
             parameterName != "futilityStop") {
         return(NULL)
     }
 
-    if (!includeAllParameters && parameterSet$.getParameterType(parameterName) == C_PARAM_NOT_APPLICABLE) {
+    if (!includeAllParameters &&
+            parameterSet$.getParameterType(parameterName) == C_PARAM_NOT_APPLICABLE &&
+            !(parameterName %in% mandatoryParameterNames)) {
         return(NULL)
     }
 
@@ -966,11 +994,12 @@ ParameterSet <- setRefClass("ParameterSet",
             return(rep(parameterValues, numberOfStages))
         }
 
-        if (length(parameterValues) == numberOfStages && 
+        if (length(parameterValues) == numberOfStages &&
                 parameterName %in% c(
                     "plannedEvents", "plannedSubjects",
                     "minNumberOfEventsPerStage", "maxNumberOfEventsPerStage",
-                    "minNumberOfSubjectsPerStage", "maxNumberOfSubjectsPerStage"
+                    "minNumberOfSubjectsPerStage", "maxNumberOfSubjectsPerStage",
+                    "allocationRatioPlanned"
                 )) {
             values <- c()
             for (stage in 1:numberOfStages) {
@@ -978,7 +1007,7 @@ ParameterSet <- setRefClass("ParameterSet",
             }
             return(values)
         }
-        
+
         if (parameterName %in% c(
                 "accrualTime", "accrualIntensity",
                 "plannedEvents", "plannedSubjects",
@@ -1071,7 +1100,8 @@ ParameterSet <- setRefClass("ParameterSet",
         niceColumnNamesEnabled,
         includeAllParameters,
         returnParametersAsCharacter,
-        tableColumnNames) {
+        tableColumnNames,
+        mandatoryParameterNames) {
     numberOfVariants <- .getMultidimensionalNumberOfVariants(parameterSet, parameterNames)
     numberOfStages <- parameterSet$.getMultidimensionalNumberOfStages(parameterNames)
 
@@ -1122,10 +1152,12 @@ ParameterSet <- setRefClass("ParameterSet",
         tryCatch(
             {
                 if (!(parameterName %in% c("stages", "adaptations", "effectList")) &&
+                        !grepl("Function$", parameterName) &&
                         (is.null(variedParameter) || parameterName != variedParameter)) {
                     columnValues <- .getDataFrameColumnValues(
                         parameterSet, parameterName,
-                        numberOfVariants, numberOfStages, includeAllParameters
+                        numberOfVariants, numberOfStages,
+                        includeAllParameters, mandatoryParameterNames
                     )
                     if (!is.null(columnValues)) {
                         columnCaption <- parameterSet$.getDataFrameColumnCaption(
@@ -1166,38 +1198,40 @@ ParameterSet <- setRefClass("ParameterSet",
             }
         )
     }
-    
+
     if (includeAllParameters) {
         extraParameterNames <- names(parameterSet)
         extraParameterNames <- extraParameterNames[!grepl("^\\.", extraParameterNames)]
         extraParameterNames <- extraParameterNames[!(extraParameterNames %in% parameterNames)]
         extraParameterNames <- unique(c(parameterNames[!(parameterNames %in% usedParameterNames)], extraParameterNames))
         for (extraParameter in extraParameterNames) {
-            tryCatch({
-                if (parameterSet$.getParameterType(extraParameter) != C_PARAM_TYPE_UNKNOWN) {
-                    value <- parameterSet[[extraParameter]] 
-                    if (!is.null(value) && length(value) > 0 && 
-                            !is.matrix(value) && !is.array(value) && !is.data.frame(value) && 
-                            (is.numeric(value) || is.character(value) || is.logical(value))) {
-                            
-                        columnCaption <- parameterSet$.getDataFrameColumnCaption(
-                            extraParameter,
-                            tableColumnNames, niceColumnNamesEnabled
-                        )
-                            
-                        if (length(value) == 1) {
-                            dataFrame[[columnCaption]] <- rep(value, nrow(dataFrame))
-                        } else {
-                            dataFrame[[columnCaption]] <- rep(.arrayToString(value, maxLength = 10), nrow(dataFrame))
+            tryCatch(
+                {
+                    if (parameterSet$.getParameterType(extraParameter) != C_PARAM_TYPE_UNKNOWN) {
+                        value <- parameterSet[[extraParameter]]
+                        if (!is.null(value) && length(value) > 0 &&
+                                !is.matrix(value) && !is.array(value) && !is.data.frame(value) &&
+                                (is.numeric(value) || is.character(value) || is.logical(value))) {
+                            columnCaption <- parameterSet$.getDataFrameColumnCaption(
+                                extraParameter,
+                                tableColumnNames, niceColumnNamesEnabled
+                            )
+
+                            if (length(value) == 1) {
+                                dataFrame[[columnCaption]] <- rep(value, nrow(dataFrame))
+                            } else {
+                                dataFrame[[columnCaption]] <- rep(.arrayToString(value, maxLength = 10), nrow(dataFrame))
+                            }
                         }
                     }
+                },
+                error = function(e) {
+                    warning(
+                        ".getAsDataFrameMultidimensional: failed to add extra parameter ",
+                        sQuote(parameterName), " to data.frame; ", e$message
+                    )
                 }
-            }, error = function(e) {
-                warning(
-                    ".getAsDataFrameMultidimensional: failed to add extra parameter ",
-                    sQuote(parameterName), " to data.frame; ", e$message
-                )
-            })
+            )
         }
     }
 
@@ -1252,9 +1286,15 @@ ParameterSet <- setRefClass("ParameterSet",
     return(dataFrame)
 }
 
-.getAsDataFrame <- function(parameterSet, parameterNames, niceColumnNamesEnabled = FALSE,
-        includeAllParameters = FALSE, handleParameterNamesAsToBeExcluded = FALSE,
-        returnParametersAsCharacter = FALSE, tableColumnNames = C_TABLE_COLUMN_NAMES) {
+.getAsDataFrame <- function(...,
+        parameterSet,
+        parameterNames,
+        niceColumnNamesEnabled = FALSE,
+        includeAllParameters = FALSE,
+        handleParameterNamesAsToBeExcluded = FALSE,
+        returnParametersAsCharacter = FALSE,
+        tableColumnNames = C_TABLE_COLUMN_NAMES,
+        mandatoryParameterNames = character(0)) {
     parameterNamesToBeExcluded <- c()
     if (handleParameterNamesAsToBeExcluded) {
         parameterNamesToBeExcluded <- parameterNames
@@ -1270,12 +1310,14 @@ ParameterSet <- setRefClass("ParameterSet",
     parametersToIgnore <- character(0)
     if (!is.null(parameterSet[[".piecewiseSurvivalTime"]]) &&
             parameterSet$.piecewiseSurvivalTime$piecewiseSurvivalEnabled) {
-        parametersToIgnore <- c(parametersToIgnore, 
-            "lambda1", "lambda2", "median1", "median2", 
-            "pi1", "pi2", "piecewiseSurvivalTime")
+        parametersToIgnore <- c(
+            parametersToIgnore,
+            "lambda1", "lambda2", "median1", "median2",
+            "pi1", "pi2", "piecewiseSurvivalTime"
+        )
         parametersToIgnore <- intersect(parametersToIgnore, parameterNames)
-    } 
-    
+    }
+
     if (parameterSet$.getParameterType("hazardRatio") == C_PARAM_GENERATED &&
             !is.null(parameterSet[[".piecewiseSurvivalTime"]]) &&
             isTRUE(parameterSet$.piecewiseSurvivalTime$piecewiseSurvivalEnabled)) {
@@ -1288,15 +1330,17 @@ ParameterSet <- setRefClass("ParameterSet",
             parametersToIgnore <- c(parametersToIgnore, c("accrualTime", "accrualIntensity"))
         }
     }
-    
+
     if (length(parametersToIgnore) > 0) {
         parameterNames <- parameterNames[!(parameterNames %in% parametersToIgnore)]
     }
 
-    if (parameterSet$.containsMultidimensionalParameters(parameterNames)) {
+    if (parameterSet$.containsMultidimensionalParameters(parameterNames) ||
+            (.isTrialDesignPlanCountData(parameterSet) && length(parameterSet$theta) > 1)) {
         return(.addDelayedInformationRates(.getAsDataFrameMultidimensional(
             parameterSet, parameterNames, niceColumnNamesEnabled,
-            includeAllParameters, returnParametersAsCharacter, tableColumnNames
+            includeAllParameters, returnParametersAsCharacter, tableColumnNames,
+            mandatoryParameterNames
         )))
     }
 
@@ -1406,11 +1450,10 @@ as.data.frame.ParameterSet <- function(x, row.names = NULL,
     .warnInCaseOfUnknownArguments(functionName = "as.data.frame", ...)
 
     return(.getAsDataFrame(
-        parameterSet = x, 
+        parameterSet = x,
         parameterNames = NULL,
-        niceColumnNamesEnabled = niceColumnNamesEnabled, 
-        includeAllParameters = includeAllParameters,
-        
+        niceColumnNamesEnabled = niceColumnNamesEnabled,
+        includeAllParameters = includeAllParameters
     ))
 }
 
@@ -1438,68 +1481,6 @@ setMethod(
     }
 )
 
-#'
-#' @title
-#' Create output in Markdown
-#'
-#' @description
-#' The \code{kable()} function returns the output of the specified object formatted in Markdown.
-#'
-#' @param x A \code{ParameterSet}. If x does not inherit from class \code{\link{ParameterSet}},
-#'        \code{knitr::kable(x)} will be returned.
-#' @param  ... Other arguments (see \code{\link[knitr]{kable}}).
-#'
-#' @details
-#' Generic function to represent a parameter set in Markdown.
-#' Use \code{options("rpact.print.heading.base.number" = "NUMBER")} (where \code{NUMBER} is an integer value >= -1) to
-#' specify the heading level. The default is \code{options("rpact.print.heading.base.number" = "0")}, i.e., the
-#' top headings start with \code{##} in Markdown. \code{options("rpact.print.heading.base.number" = "-1")} means
-#' that all headings will be written bold but are not explicit defined as header.
-#'
-#' @export
-#'
-kable.ParameterSet <- function(x, ...) {
-    fCall <- match.call(expand.dots = FALSE)
-    if (inherits(x, "ParameterSet")) {
-        objName <- deparse(fCall$x)
-        if (all(grepl("^ *print\\(", objName))) {
-            stop(
-                C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "kable(", objName, ") does not work correctly. ",
-                "Use ", sub("print", "kable", objName), " without 'print' instead or ", sub("\\)", ", markdown = TRUE)", objName)
-            )
-        }
-        
-        if (.isSimulationResults(x)) {
-            showStatistics <- .getOptionalArgument("showStatistics", optionalArgumentDefaultValue = FALSE, ...)
-            if (isTRUE(showStatistics)) {
-                return(print(x, markdown = TRUE, showStatistics = TRUE))
-            }
-        }
-        
-        return(print(x, markdown = TRUE))
-    }
-
-    .assertPackageIsInstalled("knitr")
-    knitr::kable(x, ...)
-}
-
-#'
-#' @title
-#' Create tables in Markdown
-#'
-#' @description
-#' The \code{kable()} function returns a single table for a single object that inherits from class \code{\link{ParameterSet}}.
-#'
-#' @details
-#' Generic to represent a parameter set in Markdown.
-#'
-#' @param x The object that inherits from \code{\link{ParameterSet}}.
-#' @param  ... Other arguments (see \code{\link[knitr]{kable}}).
-#'
-#' @export
-#'
-setGeneric("kable", kable.ParameterSet)
-
 #'
 #' @title
 #' Coerce Field Set to a Matrix
@@ -1588,6 +1569,9 @@ as.matrix.FieldSet <- function(x, ..., enforceRowNames = TRUE, niceColumnNamesEn
 #'
 #' @param object A \code{\link{ParameterSet}} object.
 #' @inheritParams param_digits
+#' @param output The output parts, default is \code{"all"}.
+#' @param printObject Show also the print output after the summary, default is \code{FALSE}.
+#' @param sep The separator line between the summary and the optional print output.
 #' @inheritParams param_three_dots
 #'
 #' @details
@@ -1602,16 +1586,28 @@ as.matrix.FieldSet <- function(x, ..., enforceRowNames = TRUE, niceColumnNamesEn
 #'
 #' @keywords internal
 #'
-summary.ParameterSet <- function(object, ..., type = 1, digits = NA_integer_, output = c("all", "title", "overview", "body")) {
-    .warnInCaseOfUnknownArguments(functionName = "summary", ...)
+summary.ParameterSet <- function(object, ...,
+        type = 1,
+        digits = NA_integer_,
+        output = c("all", "title", "overview", "body"),
+        printObject = FALSE,
+        sep = "\n-----\n\n") {
+    .warnInCaseOfUnknownArguments(functionName = "summary", ignore = c("printObject"), ...)
+
+    base::attr(object, "printObject") <- printObject
+    base::attr(object, "printObjectSeparator") <- sep
 
     if (type == 1 && inherits(object, "SummaryFactory")) {
         return(object)
     }
 
-    if (type == 1 && (inherits(object, "TrialDesign") || inherits(object, "TrialDesignPlan") ||
-            inherits(object, "SimulationResults") || inherits(object, "AnalysisResults") ||
-            inherits(object, "TrialDesignCharacteristics"))) {
+    if (type == 1 && (
+            inherits(object, "TrialDesign") ||
+                inherits(object, "TrialDesignPlan") ||
+                inherits(object, "SimulationResults") ||
+                inherits(object, "AnalysisResults") ||
+                inherits(object, "TrialDesignCharacteristics") ||
+                inherits(object, "PerformanceScore"))) {
         output <- match.arg(output)
         return(.createSummary(object, digits = digits, output = output))
     }
@@ -1660,14 +1656,19 @@ summary.ParameterSet <- function(object, ..., type = 1, digits = NA_integer_, ou
 #'
 #' @keywords internal
 #'
-print.ParameterSet <- function(x, ..., markdown = FALSE) {
-    if (markdown) {
-        x$.catMarkdownText()
-        return(invisible(x))
+print.ParameterSet <- function(x, ..., markdown = NA) {
+    if (is.na(markdown)) {
+        markdown <- .isMarkdownEnabled()
     }
 
-    x$show()
-    invisible(x)
+    if (markdown) {
+        x$.catMarkdownText()
+        cat("\n\n")
+    } else {
+        x$show()
+    }
+
+    return(invisible(x))
 }
 
 #'
@@ -1706,3 +1707,92 @@ plot.ParameterSet <- function(x, y, ..., main = NA_character_,
         "sorry, function 'plot' is not implemented yet for class '", .getClassName(x), "'"
     )
 }
+
+#'
+#' @title
+#' Print Parameter Set in Markdown Code Chunks
+#'
+#' @description
+#' The function `knit_print.ParameterSet` is the default printing function for rpact result objects in knitr.
+#' The chunk option `render` uses this function by default.
+#' To fall back to the normal printing behavior set the chunk option `render = normal_print`.
+#' For more information see \code{\link[knitr]{knit_print}}.
+#'
+#' @param x A \code{ParameterSet}.
+#' @param  ... Other arguments (see \code{\link[knitr]{knit_print}}).
+#'
+#' @details
+#' Generic function to print a parameter set in Markdown.
+#' Use \code{options("rpact.print.heading.base.number" = "NUMBER")} (where \code{NUMBER} is an integer value >= -1) to
+#' specify the heading level. The default is \code{options("rpact.print.heading.base.number" = "0")}, i.e., the
+#' top headings start with \code{##} in Markdown. \code{options("rpact.print.heading.base.number" = "-1")} means
+#' that all headings will be written bold but are not explicit defined as header.
+#'
+#' @export
+#'
+knit_print.ParameterSet <- function(x, ...) {
+    result <- paste0(utils::capture.output(x$.catMarkdownText()), collapse = "\n")
+    return(knitr::asis_output(result))
+}
+
+#'
+#' @title
+#' Create output in Markdown
+#'
+#' @description
+#' The \code{kable()} function returns the output of the specified object formatted in Markdown.
+#'
+#' @param x A \code{ParameterSet}. If x does not inherit from class \code{\link{ParameterSet}},
+#'        \code{knitr::kable(x)} will be returned.
+#' @param  ... Other arguments (see \code{\link[knitr]{kable}}).
+#'
+#' @details
+#' Generic function to represent a parameter set in Markdown.
+#' Use \code{options("rpact.print.heading.base.number" = "NUMBER")} (where \code{NUMBER} is an integer value >= -1) to
+#' specify the heading level. The default is \code{options("rpact.print.heading.base.number" = "0")}, i.e., the
+#' top headings start with \code{##} in Markdown. \code{options("rpact.print.heading.base.number" = "-1")} means
+#' that all headings will be written bold but are not explicit defined as header.
+#'
+#' @export
+#'
+kable.ParameterSet <- function(x, ...) {
+    fCall <- match.call(expand.dots = FALSE)
+    if (inherits(x, "ParameterSet")) {
+        objName <- deparse(fCall$x)
+        if (length(objName) > 0) {
+            if (length(objName) > 1) {
+                objName <- paste0(objName[1], "...")
+            }
+            if (grepl("^ *print\\(", objName)) {
+                stop(
+                    C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "kable(", objName, ") ",
+                    "does not work correctly. ",
+                    "Use ", sub("print", "kable", objName), " without 'print' ",
+                    "instead or ", sub("\\)", ", markdown = TRUE)", objName)
+                )
+            }
+        }
+
+        return(knit_print.ParameterSet(x = x, ...))
+    }
+
+    .assertPackageIsInstalled("knitr")
+    knitr::kable(x, ...)
+}
+
+#'
+#' @title
+#' Create tables in Markdown
+#'
+#' @description
+#' The \code{kable()} function returns a single table for a single object that inherits from class \code{\link{ParameterSet}}.
+#'
+#' @details
+#' Generic to represent a parameter set in Markdown.
+#'
+#' @param x The object that inherits from \code{\link{ParameterSet}}.
+#' @param  ... Other arguments (see \code{\link[knitr]{kable}}).
+#'
+#' @export
+#'
+setGeneric("kable", kable.ParameterSet)
