@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6805 $
-## |  Last changed: $Date: 2023-02-08 09:30:19 +0100 (Mi, 08 Feb 2023) $
+## |  File version: $Revision: 7526 $
+## |  Last changed: $Date: 2023-12-21 13:38:20 +0100 (Do, 21 Dez 2023) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -80,7 +80,11 @@ PlotSubTitleItems <- setRefClass("PlotSubTitleItems",
         addItem = function(item) {
             items <<- c(items, item)
         },
-        add = function(title, value, subscript = NA_character_, ..., digits = 3L) {
+        add = function(title, value, subscript = NA_character_, ..., digits = 3L, condition = TRUE) {
+            if (isFALSE(condition)) {
+                return(invisible())
+            }
+            
             titleTemp <- title
             if (length(items) == 0) {
                 titleTemp <- .formatCamelCase(titleTemp, title = TRUE)
@@ -296,6 +300,9 @@ PlotSettings <- setRefClass("PlotSettings",
         .pointSize = "numeric",
         .legendFontSize = "numeric",
         .htmlTitle = "character",
+        .scalingEnabled = "logical",
+        .pointScalingCorrectionEnabled = "logical",
+        .pointBorderEnabled = "logical",
         lineSize = "numeric",
         pointSize = "numeric",
         pointColor = "character",
@@ -327,6 +334,9 @@ PlotSettings <- setRefClass("PlotSettings",
             .pointSize <<- pointSize
             .legendFontSize <<- legendFontSize
             .htmlTitle <<- NA_character_
+            .scalingEnabled <<- TRUE
+            .pointScalingCorrectionEnabled <<- TRUE
+            .pointBorderEnabled <<- TRUE
 
             .parameterNames <<- list(
                 "lineSize" = "Line size",
@@ -538,7 +548,15 @@ PlotSettings <- setRefClass("PlotSettings",
             legendFontSize <<- .self$.legendFontSize * adjustingValue
         },
         scaleSize = function(size, pointEnabled = FALSE) {
+            if (isFALSE(.self$.scalingEnabled)) {
+                return(size)
+            }
+
             if (pointEnabled) {
+                if (isFALSE(.pointScalingCorrectionEnabled)) {
+                    return(size)
+                }
+
                 return(size * .self$scalingFactor^2)
             }
 
@@ -658,21 +676,27 @@ PlotSettings <- setRefClass("PlotSettings",
             return(p)
         },
         plotPoints = function(p, pointBorder, ..., mapping = NULL) {
-
             # plot white border around the points
-            if (pointBorder > 0) {
+            if (pointBorder > 0 && .pointBorderEnabled) {
                 p <- p + ggplot2::geom_point(
                     mapping = mapping,
-                    color = "white", size = scaleSize(.self$pointSize, TRUE), alpha = 1,
-                    shape = 21, stroke = pointBorder / 2.25, show.legend = FALSE
+                    color = "white",
+                    size = scaleSize(.self$pointSize, TRUE),
+                    alpha = 1,
+                    shape = 21,
+                    stroke = pointBorder / 2.25,
+                    show.legend = FALSE
                 )
             }
 
             if (!is.null(.self$pointColor) && length(.self$pointColor) == 1 && !is.na(.self$pointColor)) {
                 p <- p + ggplot2::geom_point(
                     mapping = mapping,
-                    color = .self$pointColor, size = scaleSize(.self$pointSize, TRUE), alpha = 1,
-                    shape = 19, show.legend = FALSE
+                    color = .self$pointColor,
+                    size = scaleSize(.self$pointSize, TRUE),
+                    alpha = 1,
+                    shape = 19,
+                    show.legend = FALSE
                 )
             } else {
                 p <- p + ggplot2::geom_point(
