@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6802 $
-## |  Last changed: $Date: 2023-02-07 17:07:25 +0100 (Di, 07 Feb 2023) $
+## |  File version: $Revision: 7558 $
+## |  Last changed: $Date: 2024-01-12 15:29:16 +0100 (Fri, 12 Jan 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -146,8 +146,9 @@ summary.TrialDesignSet <- function(object, ..., type = 1, digits = NA_integer_)
 #' @description
 #' \code{TrialDesignSet} is a class for creating a collection of different trial designs.
 #'
-#' @field designs The designs (optional).
-#' @field design The master design (optional).
+#' @template field_designs
+#' @template field_design
+#' @template field_variedParameters
 #'
 #' @details
 #' This object cannot be created directly; better use \code{\link[=getDesignSet]{getDesignSet()}}
@@ -632,6 +633,70 @@ length.TrialDesignSet <- function(x) {
     return(length(x$designs))
 }
 
+.getHarmonizedColumnNames <- function(df1, df2) {
+    colNames1 <- colnames(df1)
+    colNames2 <- colnames(df2)
+    if (length(colNames1) != length(colNames2)) {
+        stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, 
+            "cannot harmonize column names of two data frames if number of columns is unequal (",
+            length(colNames1), " != ", length(colNames2), ")")
+    }
+    
+    colNames <- character(0)
+    for (i in 1:length(colNames1)) {
+        colName1 <- colNames1[i]
+        colName2 <- colNames2[i]
+        if (!identical(colName1, colName2)) {
+            vec1 <- unlist(strsplit(colName1, " "))
+            vec2 <- unlist(strsplit(colName2, " "))
+            colNames <- c(colNames, paste(base::intersect(vec1, vec2), collapse = " "))
+        } else {
+            colNames <- c(colNames, colName1)
+        }
+    }
+    return(colNames)
+}
+
+.insertColumnName <- function(df, colName, colNames, at) {
+    naCol <- rep(NA, nrow(df))
+    if (at == 1) {
+        colNames <- c(colName, colNames)
+        df <- cbind(naCol, df)
+    }
+    else if (at <= length(colNames)) {
+        colNames <- c(colNames[1:(at - 1)], colName, colNames[at:length(colNames)])
+        df <- cbind(df[, 1:(at - 1)], naCol, df[, at:ncol(df)])
+    }
+    else {
+        colNames <- c(colNames, colName)
+        df <- cbind(df, naCol)
+    }
+    colnames(df) <- colNames
+    return(list(df = df, colNames = colNames))
+}
+
+.getHarmonizedDataFrames <- function(df1, df2) {
+    if (ncol(df1) == ncol(df2)) {
+        return(list(df1 = df1, df2 = df2))
+    }
+    
+    colNames1 <- colnames(df1)
+    colNames2 <- colnames(df2)
+    difference <- c(colNames1[!(colNames1 %in% colNames2)], colNames2[!(colNames2 %in% colNames1)])
+    for (colName in difference) {
+        if (colName %in% colNames1) {
+            result <- .insertColumnName(df2, colName, colNames2, at = which(colNames1 == colName))
+            colNames2 <- result$colNames
+            df2 <- result$df
+        } else {
+            result <- .insertColumnName(df1, colName, colNames1, at = which(colNames2 == colName))
+            colNames1 <- result$colNames
+            df1 <- result$df
+        }
+    }
+    return(list(df1 = df1, df2 = df2))
+}
+
 #'
 #' @title
 #' Coerce Trial Design Set to a Data Frame
@@ -661,9 +726,14 @@ length.TrialDesignSet <- function(x) {
 #'
 #' @keywords internal
 #'
-as.data.frame.TrialDesignSet <- function(x, row.names = NULL,
-        optional = FALSE, niceColumnNamesEnabled = FALSE, includeAllParameters = FALSE,
-        addPowerAndAverageSampleNumber = FALSE, theta = seq(-1, 1, 0.02), nMax = NA_integer_, ...) {
+as.data.frame.TrialDesignSet <- function(x, 
+        row.names = NULL,
+        optional = FALSE, 
+        niceColumnNamesEnabled = FALSE, 
+        includeAllParameters = FALSE,
+        addPowerAndAverageSampleNumber = FALSE, 
+        theta = seq(-1, 1, 0.02), 
+        nMax = NA_integer_, ...) {
     .assertIsTrialDesignSet(x)
     if (x$isEmpty()) {
         stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "cannot create data.frame because the design set is empty")
@@ -693,7 +763,7 @@ as.data.frame.TrialDesignSet <- function(x, row.names = NULL,
             niceColumnNamesEnabled = niceColumnNamesEnabled,
             includeAllParameters = includeAllParameters
         ))
-
+    
         if (.isTrialDesignWithValidFutilityBounds(design)) {
             futilityBoundsName <- "futilityBounds"
             if (niceColumnNamesEnabled) {
@@ -712,15 +782,16 @@ as.data.frame.TrialDesignSet <- function(x, row.names = NULL,
             kMax <- design$kMax
             df[[alpha0VecName]][kMax] <- design$criticalValues[kMax]
         }
-
+        
         if (addPowerAndAverageSampleNumber) {
             results <- PowerAndAverageSampleNumberResult(design, theta = theta, nMax = nMax)
             suppressWarnings(df2 <- as.data.frame(results,
                 niceColumnNamesEnabled = niceColumnNamesEnabled,
-                includeAllParameters = includeAllParameters
+                includeAllParameters = FALSE #includeAllParameters
             ))
             df <- merge(df, df2, all.y = TRUE)
         }
+        
         if (is.null(dataFrame)) {
             if (niceColumnNamesEnabled) {
                 dataFrame <- cbind("Design number" = rep(1, nrow(df)), df)
@@ -733,6 +804,15 @@ as.data.frame.TrialDesignSet <- function(x, row.names = NULL,
             } else {
                 df <- cbind(designNumber = rep(max(dataFrame$designNumber) + 1, nrow(df)), df)
             }
+            
+            result <- .getHarmonizedDataFrames(dataFrame, df)
+            dataFrame <- result$df1
+            df <- result$df2
+            
+            colNames <- .getHarmonizedColumnNames(dataFrame, df)
+            colnames(dataFrame) <- colNames
+            colnames(df) <- colNames
+            
             dataFrame <- rbind(dataFrame, df)
         }
     }
@@ -958,7 +1038,7 @@ plot.TrialDesignSet <- function(x, y, ..., type = 1L, main = NA_character_,
         xParameterName = xParameterName,
         yParameterNames = yParameterNames, mainTitle = main, xlab = xlab, ylab = ylab,
         palette = palette, theta = theta, nMax = nMax, plotPointsEnabled = plotPointsEnabled,
-        legendPosition = legendPosition, plotSettings = plotSettings, ...
+        legendPosition = legendPosition, plotSettings = plotSettings # , ...
     )
 
     p <- .addDecistionCriticalValuesToPlot(p = p, designMaster = designMaster, type = type, nMax = nMax)
@@ -1002,7 +1082,7 @@ plot.TrialDesignSet <- function(x, y, ..., type = 1L, main = NA_character_,
         ),
         size = plotSettings$scaleSize(plotSettings$pointSize, TRUE),
         shape = 4, stroke = 1.25, show.legend = FALSE
-    ) 
+    )
 
     for (i in 1:nrow(data)) {
         label <- paste0("(", round(data[i, 1], 3), ", ", round(data[i, 2], 3), ")")
