@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6485 $
-## |  Last changed: $Date: 2022-08-12 13:20:22 +0200 (Fr, 12 Aug 2022) $
+## |  File version: $Revision: 7535 $
+## |  Last changed: $Date: 2024-01-08 09:39:31 +0100 (Mo, 08 Jan 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -43,7 +43,7 @@ NULL
         ))
     }
 
-    .stopWithWrongDesignMessage(design)
+    .stopWithWrongDesignMessage(design, inclusiveConditionalDunnett = FALSE)
 }
 
 .getAnalysisResultsSurvivalInverseNormal <- function(..., design,
@@ -134,10 +134,12 @@ NULL
     return(results)
 }
 
-#
-# The following parameters will be taken from 'design':
-# stages, informationRate, criticalValues, futilityBounds, alphaSpent, stageLevels
-#
+#'
+#' The following parameters will be taken from 'design':
+#' stages, informationRate, criticalValues, futilityBounds, alphaSpent, stageLevels
+#'
+#' @noRd
+#'
 .getAnalysisResultsSurvivalAll <- function(..., results, design, dataInput, stage,
         directionUpper, thetaH0, thetaH1, nPlanned, allocationRatioPlanned, tolerance,
         iterations, seed) {
@@ -170,7 +172,6 @@ NULL
     results$.setParameterType("testActions", C_PARAM_GENERATED)
 
     if (design$kMax > 1) {
-
         # conditional power
         startTime <- Sys.time()
         if (.isTrialDesignFisher(design)) {
@@ -234,10 +235,9 @@ NULL
     .logProgress("Repeated p-values calculated", startTime = startTime)
 
     if (design$kMax > 1) {
-
         # final p-value
         startTime <- Sys.time()
-        finalPValue <- getFinalPValue(stageResults)
+        finalPValue <- getFinalPValue(stageResults, showWarnings = FALSE)
         results$finalPValues <- .getVectorWithFinalValueAtFinalStage(
             kMax = design$kMax,
             finalValue = finalPValue$pFinal, finalStage = finalPValue$finalStage
@@ -250,7 +250,7 @@ NULL
         # final confidence interval & median unbiased estimate
         startTime <- Sys.time()
         finalConfidenceIntervals <- .getFinalConfidenceIntervalSurvival(
-            design = design, dataInput = dataInput, thetaH0 = thetaH0, stage = stage, 
+            design = design, dataInput = dataInput, thetaH0 = thetaH0, stage = stage,
             directionUpper = directionUpper, tolerance = tolerance
         )
 
@@ -278,25 +278,29 @@ NULL
     return(results)
 }
 
-# @title
-# Get Stage Results Survival
-#
-# @description
-# Returns a stage results object
-#
-# @param design the trial design.
-#
-# @return Returns a \code{StageResultsSurvival} object.
-#
-# @keywords internal
-#
+#' @title
+#' Get Stage Results Survival
+#'
+#' @description
+#' Returns a stage results object
+#'
+#' @param design the trial design.
+#'
+#' @return Returns a \code{StageResultsSurvival} object.
+#'
+#' @keywords internal
+#'
+#' @noRd
+#'
 .getStageResultsSurvival <- function(..., design, dataInput,
         thetaH0 = C_THETA_H0_SURVIVAL_DEFAULT,
         directionUpper = C_DIRECTION_UPPER_DEFAULT,
         stage = NA_integer_, userFunctionCallEnabled = FALSE) {
     .assertIsDatasetSurvival(dataInput)
     .assertIsValidThetaH0DataInput(thetaH0, dataInput)
-    .assertIsValidDirectionUpper(directionUpper, design$sided, userFunctionCallEnabled = userFunctionCallEnabled)
+    .assertIsValidDirectionUpper(directionUpper, design$sided,
+        userFunctionCallEnabled = userFunctionCallEnabled
+    )
     .warnInCaseOfUnknownArguments(
         functionName = "getStageResultsSurvival",
         ignore = .getDesignArgumentsToIgnoreAtUnknownArgumentCheck(design, powerCalculationEnabled = TRUE), ...
@@ -376,9 +380,11 @@ NULL
     return(stageResults)
 }
 
-#
-# Calculation of lower and upper limits of repeated confidence intervals (RCIs) for Survival
-#
+#'
+#' Calculation of lower and upper limits of repeated confidence intervals (RCIs) for Survival
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsSurvival <- function(..., design) {
     if (.isTrialDesignGroupSequential(design)) {
         return(.getRepeatedConfidenceIntervalsSurvivalGroupSequential(design = design, ...))
@@ -392,7 +398,7 @@ NULL
         return(.getRepeatedConfidenceIntervalsSurvivalFisher(design = design, ...))
     }
 
-    .stopWithWrongDesignMessage(design)
+    .stopWithWrongDesignMessage(design, inclusiveConditionalDunnett = FALSE)
 }
 
 .getRootThetaSurvival <- function(..., design, dataInput, stage, directionUpper, thetaLow, thetaUp,
@@ -485,70 +491,71 @@ NULL
     repeatedConfidenceIntervals <- matrix(NA_real_, 2, design$kMax)
     for (k in (1:stage)) {
         startTime <- Sys.time()
-		if (criticalValues[k] < C_QNORM_MAXIMUM) {		
-		
-	        # Finding maximum upper and minimum lower bounds for RCIs
-	        thetaLow <- exp(.getUpperLowerThetaSurvival(
-	            design = design, dataInput = dataInput,
-	            theta = -1, stage = k, directionUpper = TRUE,
-	            conditionFunction = conditionFunction, firstParameterName = firstParameterName,
-	            secondValue = criticalValues[k]
-	        ))
-	
-	        thetaUp <- exp(.getUpperLowerThetaSurvival(
-	            design = design, dataInput = dataInput,
-	            theta = 1, stage = k, directionUpper = FALSE,
-	            conditionFunction = conditionFunction, firstParameterName = firstParameterName,
-	            secondValue = criticalValues[k]
-	        ))
-	
-	        # Finding upper and lower RCI limits through root function
-	        repeatedConfidenceIntervals[1, k] <- .getRootThetaSurvival(
-	            design = design, dataInput = dataInput, stage = k, directionUpper = C_DIRECTION_UPPER_DEFAULT,
-	            thetaLow = thetaLow, thetaUp = thetaUp, firstParameterName = firstParameterName,
-	            secondValue = criticalValues[k], tolerance = tolerance,
-	            callingFunctionInformation = paste0("Repeated confidence interval [1, ", k, "]")
-	        )
-	
-	        repeatedConfidenceIntervals[2, k] <- .getRootThetaSurvival(
-	            design = design, dataInput = dataInput, stage = k, directionUpper = FALSE,
-	            thetaLow = thetaLow, thetaUp = thetaUp, firstParameterName = firstParameterName,
-	            secondValue = criticalValues[k], tolerance = tolerance,
-	            callingFunctionInformation = paste0("Repeated confidence interval [2, ", k, "]")
-	        )
-	
-	        # Adjustment for binding futility bounds
-			if (k > 1 && !is.na(bounds[k - 1]) && conditionFunction(bounds[k - 1], border) && design$bindingFutility) {		
-	            parameterName <- ifelse(.isTrialDesignFisher(design), "pValues", firstParameterName)
-	
-	            futilityCorr[k] <- .getRootThetaSurvival(
-	                design = design, dataInput = dataInput, stage = k - 1, directionUpper = directionUpper,
-	                thetaLow = thetaLow, thetaUp = thetaUp,
-	                firstParameterName = parameterName, secondValue = bounds[k - 1], tolerance = tolerance,
-	                callingFunctionInformation = paste0("Repeated confidence interval, futility correction [", k, "]")
-	            )
-	
-	            if (directionUpper) {
-	                repeatedConfidenceIntervals[1, k] <- min(min(futilityCorr[2:k]), repeatedConfidenceIntervals[1, k])
-	            } else {
-	                repeatedConfidenceIntervals[2, k] <- max(max(futilityCorr[2:k]), repeatedConfidenceIntervals[2, k])
-	            }
-	        }
-	        .logProgress("Repeated confidence interval of stage %s calculated", startTime = startTime, k)
-	
-	        if (!is.na(repeatedConfidenceIntervals[1, k]) && !is.na(repeatedConfidenceIntervals[2, k]) &&
-	                repeatedConfidenceIntervals[1, k] > repeatedConfidenceIntervals[2, k]) {
-	            repeatedConfidenceIntervals[, k] <- rep(NA_real_, 2)
-	        }
-	    }
-	}	
+        if (criticalValues[k] < C_QNORM_MAXIMUM) {
+            # Finding maximum upper and minimum lower bounds for RCIs
+            thetaLow <- exp(.getUpperLowerThetaSurvival(
+                design = design, dataInput = dataInput,
+                theta = -1, stage = k, directionUpper = TRUE,
+                conditionFunction = conditionFunction, firstParameterName = firstParameterName,
+                secondValue = criticalValues[k]
+            ))
+
+            thetaUp <- exp(.getUpperLowerThetaSurvival(
+                design = design, dataInput = dataInput,
+                theta = 1, stage = k, directionUpper = FALSE,
+                conditionFunction = conditionFunction, firstParameterName = firstParameterName,
+                secondValue = criticalValues[k]
+            ))
+
+            # Finding upper and lower RCI limits through root function
+            repeatedConfidenceIntervals[1, k] <- .getRootThetaSurvival(
+                design = design, dataInput = dataInput, stage = k, directionUpper = C_DIRECTION_UPPER_DEFAULT,
+                thetaLow = thetaLow, thetaUp = thetaUp, firstParameterName = firstParameterName,
+                secondValue = criticalValues[k], tolerance = tolerance,
+                callingFunctionInformation = paste0("Repeated confidence interval [1, ", k, "]")
+            )
+
+            repeatedConfidenceIntervals[2, k] <- .getRootThetaSurvival(
+                design = design, dataInput = dataInput, stage = k, directionUpper = FALSE,
+                thetaLow = thetaLow, thetaUp = thetaUp, firstParameterName = firstParameterName,
+                secondValue = criticalValues[k], tolerance = tolerance,
+                callingFunctionInformation = paste0("Repeated confidence interval [2, ", k, "]")
+            )
+
+            # Adjustment for binding futility bounds
+            if (k > 1 && !is.na(bounds[k - 1]) && conditionFunction(bounds[k - 1], border) && design$bindingFutility) {
+                parameterName <- ifelse(.isTrialDesignFisher(design), "pValues", firstParameterName)
+
+                futilityCorr[k] <- .getRootThetaSurvival(
+                    design = design, dataInput = dataInput, stage = k - 1, directionUpper = directionUpper,
+                    thetaLow = thetaLow, thetaUp = thetaUp,
+                    firstParameterName = parameterName, secondValue = bounds[k - 1], tolerance = tolerance,
+                    callingFunctionInformation = paste0("Repeated confidence interval, futility correction [", k, "]")
+                )
+
+                if (directionUpper) {
+                    repeatedConfidenceIntervals[1, k] <- min(min(futilityCorr[2:k]), repeatedConfidenceIntervals[1, k])
+                } else {
+                    repeatedConfidenceIntervals[2, k] <- max(max(futilityCorr[2:k]), repeatedConfidenceIntervals[2, k])
+                }
+            }
+            .logProgress("Repeated confidence interval of stage %s calculated", startTime = startTime, k)
+
+            if (!is.na(repeatedConfidenceIntervals[1, k]) && !is.na(repeatedConfidenceIntervals[2, k]) &&
+                    repeatedConfidenceIntervals[1, k] > repeatedConfidenceIntervals[2, k]) {
+                repeatedConfidenceIntervals[, k] <- rep(NA_real_, 2)
+            }
+        }
+    }
 
     return(repeatedConfidenceIntervals)
 }
 
-#
-# RCIs based on group sequential method
-#
+#'
+#' RCIs based on group sequential method
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsSurvivalGroupSequential <- function(..., design, dataInput,
         directionUpper = C_DIRECTION_UPPER_DEFAULT, tolerance = C_ANALYSIS_TOLERANCE_DEFAULT) {
     .warnInCaseOfUnknownArguments(
@@ -563,9 +570,11 @@ NULL
     ))
 }
 
-#
-# RCIs based on inverse normal combination test
-#
+#'
+#' RCIs based on inverse normal combination test
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsSurvivalInverseNormal <- function(..., design, dataInput,
         directionUpper = C_DIRECTION_UPPER_DEFAULT, tolerance = C_ANALYSIS_TOLERANCE_DEFAULT) {
     .warnInCaseOfUnknownArguments(
@@ -580,9 +589,11 @@ NULL
     ))
 }
 
-#
-# RCIs based on Fisher's combination test
-#
+#'
+#' RCIs based on Fisher's combination test
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsSurvivalFisher <- function(..., design, dataInput,
         directionUpper = C_DIRECTION_UPPER_DEFAULT, tolerance = C_ANALYSIS_TOLERANCE_DEFAULT) {
     .warnInCaseOfUnknownArguments(
@@ -597,9 +608,11 @@ NULL
     ))
 }
 
-#
-# Calculation of conditional power based on group sequential method
-#
+#'
+#' Calculation of conditional power based on group sequential method
+#'
+#' @noRd
+#'
 .getConditionalPowerSurvivalGroupSequential <- function(..., stageResults, stage = stageResults$stage,
         allocationRatioPlanned = C_ALLOCATION_RATIO_DEFAULT, nPlanned = NA_real_, thetaH1 = NA_real_) {
     design <- stageResults$.design
@@ -703,9 +716,11 @@ NULL
     ))
 }
 
-#
-# Calculation of conditional power based on inverse normal method
-#
+#'
+#' Calculation of conditional power based on inverse normal method
+#'
+#' @noRd
+#'
 .getConditionalPowerSurvivalInverseNormal <- function(..., stageResults, stage = stageResults$stage,
         allocationRatioPlanned = C_ALLOCATION_RATIO_DEFAULT, nPlanned = NA_real_, thetaH1 = NA_real_) {
     design <- stageResults$.design
@@ -746,7 +761,6 @@ NULL
         thetaH1 <- -log(thetaH1 / stageResults$thetaH0)
     }
 
-
     # Shifted decision region for use in getGroupSeqProbs
     # Inverse normal method
     shiftedDecisionRegionUpper <- criticalValuesInverseNormal[(stage + 1):kMax] *
@@ -810,9 +824,11 @@ NULL
     ))
 }
 
-#
-# Calculation of conditional power based on Fisher combination test
-#
+#'
+#' Calculation of conditional power based on Fisher combination test
+#'
+#' @noRd
+#'
 .getConditionalPowerSurvivalFisher <- function(..., stageResults, stage = stageResults$stage,
         allocationRatioPlanned = C_ALLOCATION_RATIO_DEFAULT, nPlanned = NA_real_, thetaH1 = NA_real_,
         iterations = C_ITERATIONS_DEFAULT, seed = NA_real_) {
@@ -924,7 +940,7 @@ NULL
         results$simulated <- cp$simulated
         .updateParameterTypeOfIterationsAndSeed(results, ...)
     } else {
-        .stopWithWrongDesignMessage(stageResults$.design)
+        .stopWithWrongDesignMessage(stageResults$.design, inclusiveConditionalDunnett = FALSE)
     }
 
     results$nPlanned <- cp$nPlanned
@@ -1033,17 +1049,19 @@ NULL
     ))
 }
 
-#
-# Calculation of final confidence interval
-# based on group sequential test without SSR (general case).
-#
+#'
+#' Calculation of final confidence interval
+#' based on group sequential test without SSR (general case).
+#'
+#' @noRd
+#'
 .getFinalConfidenceIntervalSurvivalGroupSequential <- function(..., design, dataInput, stage,
         thetaH0 = C_THETA_H0_SURVIVAL_DEFAULT, directionUpper = C_DIRECTION_UPPER_DEFAULT,
         tolerance = C_ANALYSIS_TOLERANCE_DEFAULT) {
     stageResults <- .getStageResultsSurvival(
         design = design, dataInput = dataInput, stage = stage,
         thetaH0 = thetaH0, directionUpper = directionUpper
-    )    
+    )
 
     finalConfidenceIntervalGeneral <- rep(NA_real_, 2)
     medianUnbiasedGeneral <- NA_real_
@@ -1130,23 +1148,32 @@ NULL
         }
     }
 
+    if (!any(is.na(finalConfidenceIntervalGeneral))) {
+        finalConfidenceIntervalGeneral <- sort(finalConfidenceIntervalGeneral)
+    }
+    if (!any(is.na(finalConfidenceInterval))) {
+        finalConfidenceInterval <- sort(finalConfidenceInterval)
+    }
+
     return(list(
         stage = stage,
-        thetaH0 = thetaH0, 
+        thetaH0 = thetaH0,
         directionUpper = directionUpper,
-        tolerance = tolerance,            
+        tolerance = tolerance,
         finalStage = finalStage,
         medianUnbiasedGeneral = medianUnbiasedGeneral,
-        finalConfidenceIntervalGeneral = sort(finalConfidenceIntervalGeneral),
+        finalConfidenceIntervalGeneral = finalConfidenceIntervalGeneral,
         medianUnbiased = medianUnbiased,
-        finalConfidenceInterval = sort(finalConfidenceInterval)
+        finalConfidenceInterval = finalConfidenceInterval
     ))
 }
 
-#
-# Calculation of final confidence interval
-# based on inverse normal method, only valid for kMax <= 2 or no SSR.
-#
+#'
+#' Calculation of final confidence interval
+#' based on inverse normal method, only valid for kMax <= 2 or no SSR.
+#'
+#' @noRd
+#'
 .getFinalConfidenceIntervalSurvivalInverseNormal <- function(..., design, dataInput, stage,
         thetaH0 = C_THETA_H0_SURVIVAL_DEFAULT, directionUpper = C_DIRECTION_UPPER_DEFAULT,
         tolerance = C_ANALYSIS_TOLERANCE_DEFAULT) {
@@ -1245,9 +1272,9 @@ NULL
 
     return(list(
         stage = stage,
-        thetaH0 = thetaH0, 
+        thetaH0 = thetaH0,
         directionUpper = directionUpper,
-        tolerance = tolerance,            
+        tolerance = tolerance,
         finalStage = finalStage,
         medianUnbiasedGeneral = medianUnbiasedGeneral,
         finalConfidenceIntervalGeneral = sort(finalConfidenceIntervalGeneral),
@@ -1256,10 +1283,12 @@ NULL
     ))
 }
 
-#
-# Calculation of final confidence interval
-# based on Fisher combination test, only valid for kMax <= 2.
-#
+#'
+#' Calculation of final confidence interval
+#' based on Fisher combination test, only valid for kMax <= 2.
+#'
+#' @noRd
+#'
 .getFinalConfidenceIntervalSurvivalFisher <- function(..., design, dataInput, stage,
         thetaH0 = C_THETA_H0_SURVIVAL_DEFAULT, directionUpper = C_DIRECTION_UPPER_DEFAULT,
         tolerance = C_ANALYSIS_TOLERANCE_DEFAULT) {
@@ -1289,9 +1318,9 @@ NULL
 
     return(list(
         stage = stage,
-        thetaH0 = thetaH0, 
+        thetaH0 = thetaH0,
         directionUpper = directionUpper,
-        tolerance = tolerance,            
+        tolerance = tolerance,
         finalStage = finalStage,
         medianUnbiased = medianUnbiased,
         finalConfidenceInterval = finalConfidenceInterval
@@ -1346,5 +1375,5 @@ NULL
         ))
     }
 
-    .stopWithWrongDesignMessage(design)
+    .stopWithWrongDesignMessage(design, inclusiveConditionalDunnett = FALSE)
 }
