@@ -13,22 +13,25 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 5906 $
-## |  Last changed: $Date: 2022-02-26 19:10:21 +0100 (Sa, 26 Feb 2022) $
+## |  File version: $Revision: 7379 $
+## |  Last changed: $Date: 2023-10-30 16:19:12 +0100 (Mo, 30 Okt 2023) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
 #' @include f_core_utilities.R
 NULL
 
-#
-#  @title
-#  Get Multi-Armed Analysis Results
-#
-#  @description
-#  Calculates and returns the analysis results for the specified design and data.
-#
-.getAnalysisResultsMultiArm <- function(design, dataInput, ...,
+#'
+#' @title
+#' Get Multi-Armed Analysis Results
+#'
+#' @description
+#' Calculates and returns the analysis results for the specified design and data.
+#'
+#' @noRd
+#'
+.getAnalysisResultsMultiArm <- function(
+        design, dataInput, ...,
         intersectionTest = C_INTERSECTION_TEST_MULTIARMED_DEFAULT,
         directionUpper = C_DIRECTION_UPPER_DEFAULT,
         thetaH0 = NA_real_,
@@ -85,10 +88,12 @@ NULL
     stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '", .getClassName(dataInput), "' is not implemented yet")
 }
 
-#
-# Get Stage Results
-# Returns summary statistics and p-values for a given data set and a given multi-arm design.
-#
+#'
+#' Get Stage Results
+#' Returns summary statistics and p-values for a given data set and a given multi-arm design.
+#'
+#' @noRd
+#'
 .getStageResultsMultiArm <- function(design, dataInput, ...) {
     .assertIsTrialDesignInverseNormalOrFisherOrConditionalDunnett(design)
     stage <- .getStageFromOptionalArguments(..., dataInput = dataInput, design = design)
@@ -110,9 +115,12 @@ NULL
     stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '", .getClassName(dataInput), "' is not supported")
 }
 
-# Get Repeated Confidence Intervals for multi-arm case
-# Calculates and returns the lower and upper limit of the repeated confidence intervals of the trial for multi-arm designs.
-#
+#'
+#' Get Repeated Confidence Intervals for multi-arm case
+#' Calculates and returns the lower and upper limit of the repeated confidence intervals of the trial for multi-arm designs.
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsMultiArm <- function(design, dataInput, ...) {
     .assertIsTrialDesignInverseNormalOrFisherOrConditionalDunnett(design)
     stage <- .getStageFromOptionalArguments(..., dataInput = dataInput, design = design)
@@ -140,11 +148,16 @@ NULL
     stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '", .getClassName(dataInput), "' is not implemented yet")
 }
 
-#
-# Get Conditional Power for multi-arm case
-# Calculates and returns the conditional power for multi-arm case.
-#
-.getConditionalPowerMultiArm <- function(..., stageResults, nPlanned,
+#'
+#' Get Conditional Power for multi-arm case
+#' Calculates and returns the conditional power for multi-arm case.
+#'
+#' @keywords internal
+#'
+#' @noRd
+#'
+.getConditionalPowerMultiArm <- function(
+        ..., stageResults, nPlanned,
         allocationRatioPlanned = C_ALLOCATION_RATIO_DEFAULT) {
     .assertIsStageResults(stageResults)
 
@@ -198,29 +211,9 @@ NULL
     return(as.matrix(indices))
 }
 
-.getMultivariateDistribution <- function(..., type = c("normal", "t", "quantile"), upper, sigma,
-        df = NA_real_, alpha = NA_real_) {
-    .assertMnormtIsInstalled()
 
-    type <- match.arg(type)
-    if (type == "normal") {
-        return(mnormt::sadmvn(lower = -Inf, upper = upper, mean = 0, varcov = sigma))
-    } else if (type == "t") {
-        return(mnormt::sadmvt(lower = -Inf, upper = upper, mean = 0, S = sigma, df = df))
-    } else if (type == "quantile") {
-        return(.getOneDimensionalRoot(
-            function(x) {
-                return(mnormt::pmnorm(x, varcov = sigma) - (1 - alpha))
-            },
-            lower = -8,
-            upper = 8,
-            tolerance = 1e-08,
-            callingFunctionInformation = ".getMultivariateDistribution"
-        ))
-    }
-}
-
-.performClosedCombinationTest <- function(..., stageResults, design = stageResults$.design,
+.performClosedCombinationTest <- function(
+        ..., stageResults, design = stageResults$.design,
         intersectionTest = stageResults$intersectionTest) {
     dataInput <- stageResults$.dataInput
     stage <- stageResults$stage
@@ -230,6 +223,7 @@ NULL
 
     adjustedStageWisePValues <- matrix(NA_real_, nrow = 2^gMax - 1, ncol = kMax)
     adjustedOverallPValues <- matrix(NA_real_, nrow = 2^gMax - 1, ncol = kMax)
+
     overallAdjustedTestStatistics <- matrix(NA_real_, nrow = 2^gMax - 1, ncol = kMax)
     rejected <- matrix(NA, nrow = gMax, ncol = kMax)
 
@@ -445,9 +439,11 @@ getClosedCombinationTestResults <- function(stageResults) {
     ))
 }
 
-#
-# Repeated p-values for multi-arm designs
-#
+#'
+#' Repeated p-values for multi-arm designs
+#'
+#' @noRd
+#'
 .getRepeatedPValuesMultiArm <- function(stageResults, ..., tolerance = C_ANALYSIS_TOLERANCE_DEFAULT) {
     .warnInCaseOfUnknownArguments(functionName = "getRepeatedPValuesMultiArm", ...)
 
@@ -665,7 +661,7 @@ getClosedCombinationTestResults <- function(stageResults) {
 #' @family analysis functions
 #' @details
 #' For performing the conditional Dunnett test the design must be defined through the function
-#' \code{\link{getDesignConditionalDunnett}}.\cr
+#' \code{\link[=getDesignConditionalDunnett]{getDesignConditionalDunnett()}}.\cr
 #' See Koenig et al. (2008) and Wassmer & Brannath (2016), chapter 11 for details of the test procedure.
 #'
 #' @template return_object_closed_combination_test_results
@@ -700,7 +696,8 @@ getClosedConditionalDunnettTestResults <- function(stageResults, ..., stage = st
     ))
 }
 
-.getClosedConditionalDunnettTestResults <- function(...,
+.getClosedConditionalDunnettTestResults <- function(
+        ...,
         stageResults,
         design = stageResults$.design,
         stage = stageResults$stage) {
@@ -761,64 +758,73 @@ getClosedConditionalDunnettTestResults <- function(stageResults, ..., stage = st
     }
 
     for (i in 1:(2^gMax - 1)) {
-        zeta <- sqrt(frac1[indices[i, ] == 1])
-        sigma <- zeta %*% t(zeta)
-        diag(sigma) <- 1
-        crit <- .getMultivariateDistribution(
-            type = "quantile",
-            upper = NA_real_, sigma = sigma, alpha = alpha
-        )
-
-        integrand <- function(x) {
-            innerProduct <- 1
-            for (g in (1:gMax)) {
-                if (indices[i, g] == 1) {
-                    innerProduct <- innerProduct * stats::pnorm(((crit -
-                        sqrt(informationAtInterim) * signedTestStatistics[g, 1] +
-                        sqrt(1 - informationAtInterim) * sqrt(frac1[g]) * x)) /
-                        sqrt((1 - informationAtInterim) * (1 - frac1[g])))
+        tryCatch({
+        	
+            zeta <- sqrt(frac1[indices[i, ] == 1])
+            sigma <- zeta %*% t(zeta)
+            diag(sigma) <- 1
+            crit <- .getMultivariateDistribution(
+                type = "quantile",
+                upper = NA_real_, sigma = sigma, alpha = alpha
+            )
+    
+            integrandFunction <- function(x) {
+                innerProduct <- 1
+                for (g in (1:gMax)) {
+                    if (indices[i, g] == 1) {
+                        innerProduct <- innerProduct * stats::pnorm(((crit -
+                            sqrt(informationAtInterim) * signedTestStatistics[g, 1] +
+                            sqrt(1 - informationAtInterim) * sqrt(frac1[g]) * x)) /
+                            sqrt((1 - informationAtInterim) * (1 - frac1[g])))
+                    }
+                }
+                return(innerProduct * dnorm(x))
+            }
+            conditionalErrorRate[i, 1] <- 1 - stats::integrate(integrandFunction, lower = -Inf, upper = Inf)$value
+    
+        }, error = function(e) {
+            warning("Failed to calculate conditionalErrorRate[", i, ", 1]: ", e$message)
+        })
+    
+        tryCatch({
+            if (stage == 2) {
+                if (!all(is.na(stageResults$separatePValues[indices[i, ] == 1, 2]))) {
+                    if (secondStageConditioning) {
+                        maxOverallTestStatistic <- max(
+                            signedOverallTestStatistics[indices[i, ] == 1, 2],
+                            na.rm = TRUE
+                        )
+                        integrandFunctionStage2 <- function(x) {
+                            innerProduct <- 1
+                            for (g in (1:gMax)) {
+                                if ((indices[i, g] == 1) && !is.na(stageResults$overallTestStatistics[g, 2])) {
+                                    innerProduct <- innerProduct * stats::pnorm(((maxOverallTestStatistic -
+                                        sqrt(informationAtInterim) * signedTestStatistics[g, 1] +
+                                        sqrt(1 - informationAtInterim) * sqrt(frac2[g]) * x)) /
+                                        sqrt((1 - informationAtInterim) * (1 - frac2[g])))
+                                }
+                            }
+                            return(innerProduct * dnorm(x))
+                        }
+                    } else {
+                        maxTestStatistic <- max(signedTestStatistics[indices[i, ] == 1, 2], na.rm = TRUE)
+                        integrandFunctionStage2 <- function(x) {
+                            innerProduct <- 1
+                            for (g in (1:gMax)) {
+                                if ((indices[i, g] == 1) && !is.na(stageResults$separatePValues[g, 2])) {
+                                    innerProduct <- innerProduct *
+                                        stats::pnorm(((maxTestStatistic + sqrt(frac2[g]) * x)) / sqrt(1 - frac2[g]))
+                                }
+                            }
+                            return(innerProduct * dnorm(x))
+                        }
+                    }
+                    secondStagePValues[i, 2] <- 1 - stats::integrate(integrandFunctionStage2, lower = -Inf, upper = Inf)$value
                 }
             }
-            return(innerProduct * dnorm(x))
-        }
-        conditionalErrorRate[i, 1] <- 1 - integrate(integrand, lower = -Inf, upper = Inf)$value
-
-        if (stage == 2) {
-            if (!all(is.na(stageResults$separatePValues[indices[i, ] == 1, 2]))) {
-                if (secondStageConditioning) {
-                    maxOverallTestStatistic <- max(
-                        signedOverallTestStatistics[indices[i, ] == 1, 2],
-                        na.rm = TRUE
-                    )
-                    integrand <- function(x) {
-                        innerProduct <- 1
-                        for (g in (1:gMax)) {
-                            if ((indices[i, g] == 1) && !is.na(stageResults$overallTestStatistics[g, 2])) {
-                                innerProduct <- innerProduct * stats::pnorm(((maxOverallTestStatistic -
-                                    sqrt(informationAtInterim) * signedTestStatistics[g, 1] +
-                                    sqrt(1 - informationAtInterim) * sqrt(frac2[g]) * x)) /
-                                    sqrt((1 - informationAtInterim) * (1 - frac2[g])))
-                            }
-                        }
-                        return(innerProduct * dnorm(x))
-                    }
-                    secondStagePValues[i, 2] <- 1 - integrate(integrand, lower = -Inf, upper = Inf)$value
-                } else {
-                    maxTestStatistic <- max(signedTestStatistics[indices[i, ] == 1, 2], na.rm = TRUE)
-                    integrand <- function(x) {
-                        innerProduct <- 1
-                        for (g in (1:gMax)) {
-                            if ((indices[i, g] == 1) && !is.na(stageResults$separatePValues[g, 2])) {
-                                innerProduct <- innerProduct *
-                                    stats::pnorm(((maxTestStatistic + sqrt(frac2[g]) * x)) / sqrt(1 - frac2[g]))
-                            }
-                        }
-                        return(innerProduct * dnorm(x))
-                    }
-                    secondStagePValues[i, 2] <- 1 - integrate(integrand, lower = -Inf, upper = Inf)$value
-                }
-            }
-        }
+        }, error = function(e) {
+            warning("Failed to calculate secondStagePValues[", i, ", 2]: ", e$message)
+        })
     }
 
     if (stage == 2) {
@@ -875,12 +881,12 @@ getClosedConditionalDunnettTestResults <- function(stageResults, ..., stage = st
     if (stageResults$directionUpper) {
         signedTestStatistics <- stageResults$testStatistics
         signedOverallTestStatistics <- stageResults$overallTestStatistics
-        signedOverallTestStatistics[, 2] <- sqrt(informationAtInterim) * 
+        signedOverallTestStatistics[, 2] <- sqrt(informationAtInterim) *
             stageResults$testStatistics[, 1] + sqrt(1 - informationAtInterim) * stageResults$testStatistics[, 2]
     } else {
         signedTestStatistics <- -stageResults$testStatistics
         signedOverallTestStatistics <- -stageResults$overallTestStatistics
-        signedOverallTestStatistics[, 2] <- -(sqrt(informationAtInterim) * 
+        signedOverallTestStatistics[, 2] <- -(sqrt(informationAtInterim) *
             stageResults$testStatistics[, 1] + sqrt(1 - informationAtInterim) * stageResults$testStatistics[, 2])
     }
 
@@ -937,10 +943,13 @@ getClosedConditionalDunnettTestResults <- function(stageResults, ..., stage = st
     return(secondStagePValues <= conditionalErrorRate)
 }
 
-#
-#  Calculation of conditional rejection probability (CRP)
-#
-.getConditionalRejectionProbabilitiesMultiArm <- function(stageResults, ...,
+#'
+#' Calculation of conditional rejection probability (CRP)
+#'
+#' @noRd
+#'
+.getConditionalRejectionProbabilitiesMultiArm <- function(
+        stageResults, ...,
         stage = stageResults$stage, iterations = C_ITERATIONS_DEFAULT, seed = NA_real_) {
     .assertIsValidStage(stage, stageResults$.design$kMax)
     gMax <- stageResults$getGMax()
@@ -965,9 +974,11 @@ getClosedConditionalDunnettTestResults <- function(stageResults, ..., stage = st
     )
 }
 
-#
-# Calculation of CRP based on inverse normal method
-#
+#'
+#' Calculation of CRP based on inverse normal method
+#'
+#' @noRd
+#'
 .getConditionalRejectionProbabilitiesMultiArmInverseNormal <- function(..., stageResults, stage) {
     design <- stageResults$.design
     .assertIsTrialDesignInverseNormal(design)
@@ -1031,9 +1042,11 @@ getClosedConditionalDunnettTestResults <- function(stageResults, ..., stage = st
     return(conditionalRejectionProbabilities)
 }
 
-#
-# Calculation of conditional rejection probability based on Fisher's combination test
-#
+#'
+#' Calculation of conditional rejection probability based on Fisher's combination test
+#'
+#' @noRd
+#'
 .getConditionalRejectionProbabilitiesMultiArmFisher <- function(..., stageResults, stage) {
     design <- stageResults$.design
     .assertIsTrialDesignFisher(design)
@@ -1103,9 +1116,11 @@ getClosedConditionalDunnettTestResults <- function(stageResults, ..., stage = st
     return(conditionalRejectionProbabilities)
 }
 
-#
-# Calculation of CRP based on conditional Dunnett
-#
+#'
+#' Calculation of CRP based on conditional Dunnett
+#'
+#' @noRd
+#'
 .getConditionalRejectionProbabilitiesMultiArmConditionalDunnett <- function(..., stageResults) {
     design <- stageResults$.design
     .assertIsTrialDesignConditionalDunnett(design)
@@ -1132,10 +1147,13 @@ getClosedConditionalDunnettTestResults <- function(stageResults, ..., stage = st
     return(conditionalRejectionProbabilities)
 }
 
-#
-#   Plotting conditional power and likelihood
-#
-.getConditionalPowerPlotMultiArm <- function(stageResults, ...,
+#'
+#' Plotting conditional power and likelihood
+#'
+#' @noRd
+#'
+.getConditionalPowerPlotMultiArm <- function(
+        stageResults, ...,
         nPlanned, allocationRatioPlanned = C_ALLOCATION_RATIO_DEFAULT,
         thetaRange = NA_real_, assumedStDevs = NA_real_,
         piTreatmentRange = NA_real_, piControl = NA_real_,
