@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6649 $
-## |  Last changed: $Date: 2022-10-28 10:46:32 +0200 (Fri, 28 Oct 2022) $
+## |  File version: $Revision: 7206 $
+## |  Last changed: $Date: 2023-07-25 14:55:05 +0200 (Tue, 25 Jul 2023) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -213,7 +213,6 @@ NULL
     results$.setParameterType("iterations", C_PARAM_NOT_APPLICABLE)
 
     if (design$kMax > 1) {
-
         # conditional power
         startTime <- Sys.time()
         if (.isTrialDesignFisher(design)) {
@@ -307,7 +306,7 @@ NULL
     kMax <- design$kMax
 
     if (.isTrialDesignConditionalDunnett(design)) {
-        if (normalApproximation == FALSE) {
+        if (!normalApproximation) {
             if (userFunctionCallEnabled) {
                 warning("'normalApproximation' was set to TRUE ",
                     "because conditional Dunnett test was specified as design",
@@ -744,7 +743,6 @@ NULL
         }
         .logProgress("Confidence intervals for final stage calculated", startTime = startTime)
     } else {
-
         # Repeated onfidence intervals when using combination tests
         if (intersectionTest == "Hierarchical") {
             warning("Repeated confidence intervals not available for ",
@@ -775,8 +773,7 @@ NULL
         for (k in stages) {
             startTime <- Sys.time()
             for (treatmentArm in 1:gMax) {
-				if (!is.na(stageResults$testStatistics[treatmentArm, k]) && criticalValues[k] < C_QNORM_MAXIMUM) {
-
+                if (!is.na(stageResults$testStatistics[treatmentArm, k]) && criticalValues[k] < C_QNORM_MAXIMUM) {
                     # finding maximum upper and minimum lower bounds for RCIs
                     thetaLow <- .getUpperLowerThetaMeansMultiArm(
                         design = design, dataInput = dataInput,
@@ -816,7 +813,7 @@ NULL
                     )
 
                     # adjustment for binding futility bounds
-					if (k > 1 && !is.na(bounds[k - 1]) && conditionFunction(bounds[k - 1], border) && design$bindingFutility) {
+                    if (k > 1 && !is.na(bounds[k - 1]) && conditionFunction(bounds[k - 1], border) && design$bindingFutility) {
                         parameterName <- ifelse(.isTrialDesignFisher(design),
                             "singleStepAdjustedPValues", firstParameterName
                         )
@@ -881,9 +878,11 @@ NULL
     return(repeatedConfidenceIntervals)
 }
 
-#
-# RCIs based on inverse normal combination test
-#
+#'
+#' RCIs based on inverse normal combination test
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsMeansMultiArmInverseNormal <- function(...,
         design, dataInput,
         normalApproximation = C_NORMAL_APPROXIMATION_MEANS_DEFAULT,
@@ -905,9 +904,11 @@ NULL
     ))
 }
 
-#
-# RCIs based on Fisher's combination test
-#
+#'
+#' RCIs based on Fisher's combination test
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsMeansMultiArmFisher <- function(...,
         design, dataInput,
         normalApproximation = C_NORMAL_APPROXIMATION_MEANS_DEFAULT,
@@ -929,9 +930,11 @@ NULL
     ))
 }
 
-#
-# CIs based on conditional Dunnett test
-#
+#'
+#' CIs based on conditional Dunnett test
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsMeansMultiArmConditionalDunnett <- function(...,
         design, dataInput,
         normalApproximation = C_NORMAL_APPROXIMATION_MEANS_DEFAULT,
@@ -956,9 +959,11 @@ NULL
     ))
 }
 
-#
-#  Calculation of lower and upper limits of repeated confidence intervals (RCIs) for Means
-#
+#'
+#' Calculation of lower and upper limits of repeated confidence intervals (RCIs) for Means
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsMeansMultiArm <- function(..., design) {
     if (.isTrialDesignInverseNormal(design)) {
         return(.getRepeatedConfidenceIntervalsMeansMultiArmInverseNormal(design = design, ...))
@@ -972,9 +977,11 @@ NULL
     .stopWithWrongDesignMessage(design)
 }
 
-#
-#  Calculation of conditional power for Means
-#
+#'
+#' Calculation of conditional power for Means
+#'
+#' @noRd
+#'
 .getConditionalPowerMeansMultiArm <- function(..., stageResults, stage = stageResults$stage,
         nPlanned, allocationRatioPlanned = C_ALLOCATION_RATIO_DEFAULT,
         thetaH1 = NA_real_, assumedStDevs = NA_real_,
@@ -1080,9 +1087,11 @@ NULL
     )
 }
 
-#
-# Calculation of conditional power based on inverse normal method
-#
+#'
+#' Calculation of conditional power based on inverse normal method
+#'
+#' @noRd
+#'
 .getConditionalPowerMeansMultiArmInverseNormal <- function(..., results, stageResults, stage,
         allocationRatioPlanned, nPlanned, thetaH1, assumedStDevs) {
     design <- stageResults$.design
@@ -1171,9 +1180,11 @@ NULL
     return(results)
 }
 
-#
-# Calculation of conditional power based on Fisher's combination test
-#
+#'
+#' Calculation of conditional power based on Fisher's combination test
+#'
+#' @noRd
+#'
 .getConditionalPowerMeansMultiArmFisher <- function(..., results, stageResults, stage,
         allocationRatioPlanned, nPlanned, thetaH1, assumedStDevs,
         iterations, seed) {
@@ -1275,9 +1286,11 @@ NULL
     return(results)
 }
 
-#
-# Calculation of conditional power based on conditional Dunnett test
-#
+#'
+#' Calculation of conditional power based on conditional Dunnett test
+#'
+#' @noRd
+#'
 .getConditionalPowerMeansMultiArmConditionalDunnett <- function(..., results, stageResults, stage,
         allocationRatioPlanned, nPlanned, thetaH1, assumedStDevs) {
     design <- stageResults$.design
@@ -1332,9 +1345,11 @@ NULL
     return(results)
 }
 
-#
-# Calculation of conditional power and likelihood values for plotting the graph
-#
+#'
+#' Calculation of conditional power and likelihood values for plotting the graph
+#'
+#' @noRd
+#'
 .getConditionalPowerLikelihoodMeansMultiArm <- function(..., stageResults, stage,
         nPlanned, allocationRatioPlanned = C_ALLOCATION_RATIO_DEFAULT,
         thetaRange, assumedStDevs = NA_real_,
