@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6485 $
-## |  Last changed: $Date: 2022-08-12 13:20:22 +0200 (Fr, 12 Aug 2022) $
+## |  File version: $Revision: 7268 $
+## |  Last changed: $Date: 2023-09-06 15:04:31 +0200 (Mi, 06 Sep 2023) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -328,6 +328,7 @@ NULL
 
 .createDataFrame <- function(...) {
     args <- list(...)
+    args <- .removeDesignFromArgs(args)
     argNames <- .getArgumentNames(...)
     if (length(args) == 0 || length(argNames) == 0) {
         stop(C_EXCEPTION_TYPE_MISSING_ARGUMENT, "data.frame or data vectors expected")
@@ -548,6 +549,45 @@ NULL
     return(dataFrame)
 }
 
+.getDesignFromArgs <- function(...) {
+    args <- list(...)
+    if (length(args) == 0) {
+        return(NULL)
+    }
+
+    for (arg in args) {
+        if (.isTrialDesign(arg)) {
+            return(arg)
+        }
+    }
+
+    return(NULL)
+}
+
+.getDatasetFromArgs <- function(...) {
+    args <- list(...)
+    if (length(args) == 0) {
+        return(NULL)
+    }
+
+    for (arg in args) {
+        if (.isDataset(arg)) {
+            return(arg)
+        }
+    }
+
+    return(NULL)
+}
+
+.removeDesignFromArgs <- function(args) {
+    for (i in 1:length(args)) {
+        if (.isTrialDesign(args[[i]])) {
+            return(args[-i])
+        }
+    }
+    return(args)
+}
+
 .getArgumentNames <- function(...) {
     dataFrame <- .getDataFrameFromArgs(...)
     if (!is.null(dataFrame)) {
@@ -559,6 +599,8 @@ NULL
         return(character(0))
     }
 
+    args <- .removeDesignFromArgs(args)
+
     return(names(args))
 }
 
@@ -675,7 +717,7 @@ NULL
     if (length(argNames) == 0) {
         return(FALSE)
     }
-    
+
     dataObjectkeyWords <- .getAllParameterNameVariants(dataObjectkeyWords)
     matching <- intersect(argNames, dataObjectkeyWords)
     return(length(matching) > 0)
@@ -688,7 +730,7 @@ NULL
     if (!enrichmentEnabled) {
         return(FALSE)
     }
-    
+
     args <- list(...)
     if (length(args) == 1 && is.data.frame(args[[1]])) {
         data <- args[[1]]
@@ -696,7 +738,7 @@ NULL
             return(FALSE)
         }
     }
-    
+
     return(enrichmentEnabled)
 }
 
@@ -767,7 +809,7 @@ NULL
 #' the different groups are in separate columns.
 #'
 #' @seealso
-#' \code{\link{getLongFormat}} for returning the dataset as a \code{\link[base]{data.frame}} in long format.
+#' \code{\link[=getLongFormat]{getLongFormat()}} for returning the dataset as a \code{\link[base]{data.frame}} in long format.
 #'
 #' @return A \code{\link[base]{data.frame}} will be returned.
 #'
@@ -782,7 +824,7 @@ getWideFormat <- function(dataInput) {
     if (!dataInput$.enrichmentEnabled) {
         paramNames <- paramNames[!(paramNames %in% c("subsets"))]
     }
-    
+
     numberOfSubsets <- dataInput$getNumberOfSubsets()
     numberOfGroups <- dataInput$getNumberOfGroups(survivalCorrectionEnabled = FALSE)
     if (numberOfSubsets <= 1) {
@@ -892,7 +934,7 @@ getWideFormat <- function(dataInput) {
 #' the data for the different groups are in one column and the dataset contains an additional "group" column.
 #'
 #' @seealso
-#' \code{\link{getWideFormat}} for returning the dataset as a \code{\link[base]{data.frame}} in wide format.
+#' \code{\link[=getWideFormat]{getWideFormat()}} for returning the dataset as a \code{\link[base]{data.frame}} in wide format.
 #'
 #' @return A \code{\link[base]{data.frame}} will be returned.
 #'
@@ -979,8 +1021,9 @@ getLongFormat <- function(dataInput) {
 #'
 #' @seealso
 #' \itemize{
-#'   \item \code{\link{getAnalysisResults}} for using \code{getObservedInformationRates} implicit,
-#'   \item https://www.rpact.com/vignettes/rpact_boundary_update_example
+#'   \item \code{\link[=getAnalysisResults]{getAnalysisResults()}} for using
+#'         \code{getObservedInformationRates()} implicit,
+#'   \item \href{https://www.rpact.org/vignettes/planning/rpact_boundary_update_example/}{www.rpact.org/vignettes/planning/rpact_boundary_update_example}
 #' }
 #'
 #' @examples
@@ -1004,7 +1047,9 @@ getLongFormat <- function(dataInput) {
 #' getObservedInformationRates(data,
 #'     maxInformation = 46, informationEpsilon = 0.03
 #' )
-#' 
+#'
+#' @return Returns a list that summarizes the observed information rates.
+#'
 #' @export
 #'
 getObservedInformationRates <- function(dataInput, ...,
@@ -1134,22 +1179,25 @@ getObservedInformationRates <- function(dataInput, ...,
 
 .synchronizeIterationsAndSeed <- function(results) {
     if (is.null(results[[".conditionalPowerResults"]])) {
-        stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, sQuote(.getClassName(results)), 
-            " does not contain field ", sQuote(".conditionalPowerResults"))
+        stop(
+            C_EXCEPTION_TYPE_RUNTIME_ISSUE, sQuote(.getClassName(results)),
+            " does not contain field ", sQuote(".conditionalPowerResults")
+        )
     }
-    
+
     if (results$.design$kMax == 1) {
         return(invisible(results))
     }
-    
+
     if (results$.conditionalPowerResults$simulated) {
         results$conditionalPowerSimulated <- results$.conditionalPowerResults$conditionalPower
         results$.setParameterType("conditionalPower", C_PARAM_NOT_APPLICABLE)
         results$.setParameterType("conditionalPowerSimulated", C_PARAM_GENERATED)
-    
+
         results$.setParameterType("seed", results$.conditionalPowerResults$.getParameterType("seed"))
         results$seed <- results$.conditionalPowerResults$seed
-        results$.setParameterType("iterations",
+        results$.setParameterType(
+            "iterations",
             results$.conditionalPowerResults$.getParameterType("iterations")
         )
         results$iterations <- results$.conditionalPowerResults$iterations
@@ -1162,11 +1210,11 @@ getObservedInformationRates <- function(dataInput, ...,
         }
         results$.setParameterType("conditionalPower", C_PARAM_GENERATED)
         results$.setParameterType("conditionalPowerSimulated", C_PARAM_NOT_APPLICABLE)
-        
+
         results$.setParameterType("seed", C_PARAM_NOT_APPLICABLE)
         results$.setParameterType("iterations", C_PARAM_NOT_APPLICABLE)
     }
-    
+
     return(invisible(results))
 }
 
@@ -1178,17 +1226,18 @@ getObservedInformationRates <- function(dataInput, ...,
         results$.setParameterType("seed", C_PARAM_NOT_APPLICABLE)
         return(invisible(results))
     }
-    
+
     iterations <- .getOptionalArgument("iterations", ...)
-    results$.setParameterType("iterations", ifelse(is.null(iterations) || is.na(iterations) || 
-            identical(iterations, C_ITERATIONS_DEFAULT),
-        C_PARAM_DEFAULT_VALUE, C_PARAM_USER_DEFINED
+    results$.setParameterType("iterations", ifelse(is.null(iterations) || is.na(iterations) ||
+        identical(iterations, C_ITERATIONS_DEFAULT),
+    C_PARAM_DEFAULT_VALUE, C_PARAM_USER_DEFINED
     ))
-    
+
     seed <- .getOptionalArgument("seed", ...)
     results$.setParameterType("seed", ifelse(!is.null(seed) && !is.na(seed),
         C_PARAM_USER_DEFINED, C_PARAM_DEFAULT_VALUE
     ))
-    
+
     return(invisible(results))
 }
+
