@@ -13,9 +13,9 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6801 $
-## |  Last changed: $Date: 2023-02-06 15:29:57 +0100 (Mon, 06 Feb 2023) $
-## |  Last changed by: $Author: pahlke $
+## |  File version: $Revision: 7590 $
+## |  Last changed: $Date: 2024-01-23 11:32:01 +0100 (Di, 23 Jan 2024) $
+## |  Last changed by: $Author: wassmer $
 ## |
 
 #' @include f_core_utilities.R
@@ -539,7 +539,7 @@ C_PARAMETER_NAMES <- list(
     expectedNumberOfSubjectsH01 = "Expected number of subjects under H0/H1",
     expectedNumberOfSubjectsH1 = "Expected number of subjects under H1",
     expectedNumberOfSubjects = "Expected number of subjects",
-    omega = "Probability of an event",
+    chi = "Probability of an event",
     hazardRatio = "Hazard ratio",
     hazardRatios = "Hazard ratios",
     typeOfComputation = "Type of computation",
@@ -687,7 +687,29 @@ C_PARAMETER_NAMES <- list(
     situation = "Situation",
     delayedInformation = "Delayed information",
     decisionCriticalValues = "Decision critical values",
-    reversalProbabilities = "Reversal probabilities"
+    reversalProbabilities = "Reversal probabilities",
+    locationSampleSize = "Location sample sizes",
+    variationSampleSize = "Variation sample sizes",
+    subscoreSampleSize = "Sub-score sample sizes",
+    locationConditionalPower = "Location conditional power",
+    variationConditionalPower = "Variation conditional power",
+    subscoreConditionalPower = "Sub-score conditional power",
+    performanceScore = "Performance scores",
+    
+    overdispersion = "Overdispersion",
+    lambda = "Lambda",
+    fixedExposureTime = "Fixed exposure time",
+    calendarTime = "Calendar time",
+    studyTime = "Study time",
+    studySubjects = "Study subjects",
+    expectedStudyDurationH1 = "Expected study duration under H1",
+    informationOverStages = "Information over stages",
+    maxInformation = "Maximum information",
+    expectedInformationH0 = "Expected information under H0",
+    expectedInformationH01 = "Expected information under H0/H1",
+    expectedInformationH1 = "Expected information under H1",
+    plannedMaxSubjects = "Planned maximum number of subjects",
+    plannedCalendarTime = "Planned calendar time"
 )
 
 C_TABLE_COLUMN_NAMES <- list(
@@ -839,7 +861,7 @@ C_TABLE_COLUMN_NAMES <- list(
     expectedNumberOfSubjectsH01 = "Expected # subjects under H0/H1",
     expectedNumberOfSubjectsH1 = "Expected # subjects under H1",
     expectedNumberOfSubjects = "Expected # subjects",
-    omega = "Probability of an event",
+    chi = "Probability of an event",
     hazardRatio = "Hazard ratio",
     hazardRatios = "Hazard ratios",
     typeOfComputation = "Type of computation",
@@ -979,7 +1001,29 @@ C_TABLE_COLUMN_NAMES <- list(
     situation = "Situation",
     delayedInformation = "Delayed information",
     decisionCriticalValues = "Decision critical value",
-    reversalProbabilities = "Reversal probability"
+    reversalProbabilities = "Reversal probability",
+    locationSampleSize = "Location sample size",
+    variationSampleSize = "Variation sample size",
+    subscoreSampleSize = "Sub-score sample size",
+    locationConditionalPower = "Location conditional power",
+    variationConditionalPower = "Variation conditional power",
+    subscoreConditionalPower = "Sub-score conditional power",
+    performanceScore = "Performance score",
+    
+    overdispersion = "Overdispersion",
+    lambda = "Lambda",
+    fixedExposureTime = "Fixed exposure time",
+    calendarTime = "Calendar time",
+    studyTime = "Study time",
+    studySubjects = "Study subjects",
+    expectedStudyDurationH1 = "Expected study duration under H1",
+    informationOverStages = "Information over stages",
+    maxInformation = "Maximum information",
+    expectedInformationH0 = "Expected information under H0",
+    expectedInformationH01 = "Expected information under H0/H1",
+    expectedInformationH1 = "Expected information under H1",
+    plannedMaxSubjects = "Planned max. number of subjects",
+    plannedCalendarTime = "Planned calendar time"
 )
 
 .getParameterCaptions <- function(captionList, ...,
@@ -989,6 +1033,7 @@ C_TABLE_COLUMN_NAMES <- list(
         analysisResults = NULL,
         dataset = NULL,
         designCharacteristics = NULL,
+        designSet = NULL,
         tableColumns = FALSE) {
     parameterNames <- captionList
 
@@ -1009,6 +1054,15 @@ C_TABLE_COLUMN_NAMES <- list(
             parameterNameFutilityBounds <- "futilityBoundsNonBinding"
         }
         parameterNames$futilityBounds <- captionList[[parameterNameFutilityBounds]]
+        if (!is.null(designSet) && length(designSet$designs) > 1) {
+            bindingFutilityValues <- logical(0)
+            for (design in designSet$designs) {
+                bindingFutilityValues <- unique(c(bindingFutilityValues, design$bindingFutility))
+            }
+            if (length(bindingFutilityValues) > 1) {
+                parameterNames$futilityBounds <- "Futility bound"
+            }
+        }
     }
 
     if (!is.null(designPlan) && inherits(designPlan, "TrialDesignPlanSurvival") &&
@@ -1087,7 +1141,8 @@ C_TABLE_COLUMN_NAMES <- list(
         stageResults = NULL,
         analysisResults = NULL,
         dataset = NULL,
-        designCharacteristics = NULL) {
+        designCharacteristics = NULL,
+        designSet = NULL) {
     .getParameterCaptions(
         captionList = C_TABLE_COLUMN_NAMES,
         design = design,
@@ -1096,6 +1151,7 @@ C_TABLE_COLUMN_NAMES <- list(
         analysisResults = analysisResults,
         dataset = dataset,
         designCharacteristics = designCharacteristics,
+        designSet = designSet,
         tableColumns = TRUE
     )
 }
@@ -1191,7 +1247,7 @@ C_PARAMETER_FORMAT_FUNCTIONS <- list(
     expectedNumberOfSubjectsH01 = ".formatSampleSizes",
     expectedNumberOfSubjectsH1 = ".formatSampleSizes",
     expectedNumberOfSubjects = ".formatSampleSizes",
-    omega = ".formatRates",
+    chi = ".formatRates",
     hazardRatio = ".formatRates",
     hazardRatios = ".formatRates",
     pi1 = ".formatRates",
@@ -1293,5 +1349,25 @@ C_PARAMETER_FORMAT_FUNCTIONS <- list(
     informationEpsilon = ".formatProbabilities",
     delayedInformation = ".formatRates",
     decisionCriticalValues = ".formatCriticalValues",
-    reversalProbabilities = ".formatProbabilities"
+    reversalProbabilities = ".formatProbabilities",
+    locationSampleSize = ".formatProbabilities",
+    variationSampleSize = ".formatProbabilities",
+    subscoreSampleSize = ".formatProbabilities",
+    locationConditionalPower = ".formatProbabilities",
+    variationConditionalPower = ".formatProbabilities",
+    subscoreConditionalPower = ".formatProbabilities",
+    performanceScore = ".formatProbabilities",
+    
+    overdispersion = ".formatStDevs",
+    lambda = ".formatRates",
+    fixedExposureTime = ".formatTime",
+    calendarTime = ".formatTime",
+    studyTime = ".formatTime",
+    studySubjects = ".formatSampleSizes",
+    expectedStudyDurationH1 = ".formatTime",
+    informationOverStages = ".formatRatesDynamic",
+    expectedInformationH0 = ".formatRatesDynamic",
+    expectedInformationH01 = ".formatRatesDynamic",
+    expectedInformationH1 = ".formatRatesDynamic",
+    plannedMaxSubjects = ".formatSampleSizes"
 )
