@@ -13,11 +13,12 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6585 $
-## |  Last changed: $Date: 2022-09-23 14:23:08 +0200 (Fr, 23 Sep 2022) $
+## |  File version: $Revision: 7383 $
+## |  Last changed: $Date: 2023-11-02 15:18:21 +0100 (Do, 02 Nov 2023) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
+#' @include f_core_constants.R
 #' @include f_core_utilities.R
 NULL
 
@@ -136,7 +137,7 @@ C_OUTPUT_FORMAT_DEFAULT_VALUES <- pairlist(
         return(4)
     }
 
-    fv <- .getFormattedValue(value[value >= 1e-4], digits = 4, nsmall = 4)
+    fv <- .getFormattedValue(value[value >= 1e-04], digits = 4, nsmall = 4)
     fv <- fv[!((1:length(fv)) %in% grep("e", fv))]
     numberOfCharacters <- ifelse(length(fv) > 0, nchar(fv[1]), 6)
     numberOfCharacters <- ifelse(numberOfCharacters < 6, 6, numberOfCharacters)
@@ -1201,6 +1202,14 @@ getOutputFormat <- function(parameterName = NA_character_, ...,
 }
 
 .getOutputFormatKeyByFieldName <- function(fieldName) {
+    if (is.null(fieldName) || length(fieldName) != 1 || is.na(fieldName)) {
+        return(NULL)
+    }
+    
+    if (!(fieldName %in% names(C_PARAMETER_FORMAT_FUNCTIONS))) {
+        return(NULL)
+    }
+    
     functionName <- C_PARAMETER_FORMAT_FUNCTIONS[[fieldName]]
     if (is.null(functionName)) {
         return(NULL)
