@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6585 $
-## |  Last changed: $Date: 2022-09-23 14:23:08 +0200 (Fr, 23 Sep 2022) $
+## |  File version: $Revision: 7558 $
+## |  Last changed: $Date: 2024-01-12 15:29:16 +0100 (Fri, 12 Jan 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -311,7 +311,7 @@ plotTypes <- function(obj, output = c("numeric", "caption", "numcap", "capnum"),
         return(TRUE)
     }
 
-    for (param in c("alternative", "pi1", "hazardRatio")) {
+    for (param in c("alternative", "pi1", "hazardRatio", "muMaxVector", "piMaxVector", "omegaMaxVector")) {
         if (!is.null(resultObject[[param]]) &&
                 resultObject$.getParameterType(param) != C_PARAM_NOT_APPLICABLE &&
                 (any(is.na(resultObject[[param]])) ||
@@ -372,8 +372,9 @@ plotTypes <- function(obj, output = c("numeric", "caption", "numcap", "capnum"),
 #'   \item \code{capnum}:  list with caption and number
 #' }
 #'
-#' @return Depending on how the \code{output} is specified,
-#' a numeric vector, a character vector, or a list will be returned.
+#' @return Returns a list if \code{option} is either \code{capnum} or \code{numcap}
+#' or returns a vector that is of  character type for \code{option=caption} or
+#' of numeric type for \code{option=numeric}.
 #'
 #' @examples
 #' design <- getDesignInverseNormal(kMax = 2)
@@ -381,7 +382,7 @@ plotTypes <- function(obj, output = c("numeric", "caption", "numcap", "capnum"),
 #' plotTypes(design, "caption")
 #' getAvailablePlotTypes(design, "numcap")
 #' plotTypes(design, "capnum")
-#' 
+#'
 #' @export
 #'
 getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap", "capnum"),
@@ -400,15 +401,31 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
     types <- integer(0)
     if (inherits(obj, "TrialDesignPlan")) {
         if (obj$.design$kMax > 1) {
-            types <- c(types, 1:4)
+            types <- c(types, 1)
+            if (!.isTrialDesignPlanCountData(obj)) {
+                types <- c(types, 2)
+            }
+            types <- c(types, 3:4)
         }
-        types <- c(types, 5)
         if (obj$.isSampleSizeObject()) {
+            if (!.isTrialDesignPlanCountData(obj) || length(obj[["theta"]]) > 1) {
+                types <- c(types, 5)
+            }
             if (.isTrialDesignPlanSurvival(obj)) {
                 types <- c(types, 13, 14)
             }
         } else {
-            types <- c(types, 6:9)
+            if (obj$.design$kMax > 1) {
+                types <- c(types, 5, 6)
+            }
+            types <- c(types, 7)
+            if (obj$.design$kMax > 1) {
+                types <- c(types, 8)
+                if (!.isTrialDesignPlanCountData(obj) ||
+                        obj$.getParameterType("expectedNumberOfSubjectsH1") == C_PARAM_GENERATED) {
+                    types <- c(types, 9)
+                }
+            }
             if (.isTrialDesignPlanSurvival(obj)) {
                 types <- c(types, 10:14)
             }
@@ -448,7 +465,11 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
         if (inherits(obj, "SimulationResultsSurvival")) {
             types <- c(types, 10:14)
         }
-        types <- .removeInvalidPlotTypes(obj, types, c(4:14))
+        plotTypesToCheck <- c(4:14)
+        if (grepl("MultiArm", .getClassName(obj))) {
+            plotTypesToCheck <- c(1:14)
+        }
+        types <- .removeInvalidPlotTypes(obj, types, plotTypesToCheck)
     } else if (inherits(obj, "TrialDesign") || inherits(obj, "TrialDesignSet")) {
         design <- obj
         if (inherits(obj, "TrialDesignSet")) {
@@ -509,6 +530,10 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
 }
 
 .getVariedParameterHint <- function(variedParameter, variedParameterName) {
+    if (length(variedParameter) != 2) {
+        return("")
+    }
+    
     return(paste0(
         "Note: interim values between ", round(variedParameter[1], 4), " and ",
         round(variedParameter[2], 4), " were calculated to get smoother lines; use, e.g., '",
@@ -517,26 +542,6 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
     ))
 }
 
-.reconstructSequenceCommand <- function(values) {
-    if (length(values) == 0 || all(is.na(values))) {
-        return(NA_character_)
-    }
-
-    if (length(values) <= 3) {
-        return(.arrayToString(values, vectorLookAndFeelEnabled = (length(values) != 1)))
-    }
-
-    minValue <- min(values)
-    maxValue <- max(values)
-    by <- (maxValue - minValue) / (length(values) - 1)
-    valuesTemp <- seq(minValue, maxValue, by)
-    if (identical(values, valuesTemp)) {
-        return(paste0("seq(", minValue, ", ", maxValue, ", ", by, ")"))
-    }
-
-    return(.arrayToString(values, vectorLookAndFeelEnabled = TRUE, maxLength = 10))
-}
-
 .getRexepSaveCharacter <- function(x) {
     x <- gsub("\\$", "\\\\$", x)
     x <- gsub("\\.", "\\\\.", x)
@@ -709,9 +714,14 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
     return(invisible(FALSE))
 }
 
-.getParameterSetAsDataFrame <- function(parameterSet, designMaster,
+.getParameterSetAsDataFrame <- function(...,
+        parameterSet,
+        designMaster,
         addPowerAndAverageSampleNumber = FALSE,
-        theta = seq(-1, 1, 0.02), nMax = NA_integer_, yParameterNames = character(0)) {
+        theta = seq(-1, 1, 0.02),
+        nMax = NA_integer_,
+        mandatoryParameterNames = character(0),
+        yParameterNames = character(0)) {
     if (.isTrialDesignSet(parameterSet) && parameterSet$getSize() > 1 &&
             (is.null(parameterSet$variedParameters) || length(parameterSet$variedParameters) == 0)) {
         stop(
@@ -721,21 +731,29 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
     }
 
     if (inherits(parameterSet, "TrialDesignSet")) {
-        suppressWarnings(data <- as.data.frame(parameterSet,
+        suppressWarnings(data <- as.data.frame(
+            parameterSet,
             niceColumnNamesEnabled = FALSE,
-            includeAllParameters = TRUE, 
+            includeAllParameters = TRUE,
             addPowerAndAverageSampleNumber = addPowerAndAverageSampleNumber,
-            theta = theta, nMax = nMax
+            theta = theta, 
+            nMax = nMax
         ))
     } else {
-        suppressWarnings(data <- as.data.frame(parameterSet, niceColumnNamesEnabled = FALSE, 
-            includeAllParameters = TRUE))
+        parameterNames <- parameterSet$.getVisibleFieldNamesOrdered()
+        suppressWarnings(data <- .getAsDataFrame(
+            parameterSet = parameterSet,
+            parameterNames = parameterNames,
+            niceColumnNamesEnabled = FALSE,
+            includeAllParameters = FALSE,
+            mandatoryParameterNames = mandatoryParameterNames
+        ))
     }
 
     if (!.isTrialDesignSet(parameterSet)) {
         variedParameters <- logical(0)
         if ("stages" %in% colnames(data)) {
-            if ((!.isTrialDesignPlan(parameterSet) && !("overallReject" %in% yParameterNames)) || 
+            if ((!.isTrialDesignPlan(parameterSet) && !("overallReject" %in% yParameterNames)) ||
                     any(grepl("rejectPerStage|numberOfSubjects", yParameterNames))) {
                 variedParameters <- "stages"
                 names(variedParameters) <- "Stage"
@@ -878,11 +896,17 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
     }
 
     if (.isParameterSet(parameterSet) || .isTrialDesignSet(parameterSet)) {
-        df <- .getParameterSetAsDataFrame(parameterSet, designMaster,
+        df <- .getParameterSetAsDataFrame(
+            parameterSet = parameterSet,
+            designMaster = designMaster,
             addPowerAndAverageSampleNumber = addPowerAndAverageSampleNumber,
-            theta = theta, nMax = nMax, yParameterNames = yParameterNames
+            theta = theta,
+            nMax = nMax,
+            mandatoryParameterNames = c(xParameterName, yParameterNames),
+            yParameterNames = yParameterNames
         )
         data <- df$data
+        
         variedParameters <- df$variedParameters
         variedParameters <- na.omit(variedParameters)
         variedParameters <- variedParameters[variedParameters != "NA"]
@@ -922,7 +946,8 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
 
     mirrorModeEnabled <- any(grepl("Mirrored$", yParameterNames))
 
-    tableColumnNames <- .getTableColumnNames(design = designMaster)
+    tableColumnNames <- .getTableColumnNames(design = designMaster, 
+        designSet = if (.isTrialDesignSet(parameterSet)) parameterSet else NULL)
 
     xAxisLabel <- .getAxisLabel(xParameterName, tableColumnNames)
     yAxisLabel1 <- .getAxisLabel(yParameterName1, tableColumnNames)
@@ -953,13 +978,24 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
             yAxisLabel1 <- paste0(yAxisLabel1, " (", .getAxisLabel(yParameterName1, tableColumnNames), ")")
         }
     }
-    
-    yAxisLabel1 <- sub(paste0(C_PARAMETER_NAMES[["futilityBoundsDelayedInformation"]], " and"), 
-        "Lower and", yAxisLabel1, fixed = TRUE)
-    yAxisLabel1 <- sub(paste0(C_PARAMETER_NAMES[["futilityBoundsDelayedInformationNonBinding"]], " and"), 
-        "Lower and", yAxisLabel1, fixed = TRUE)
 
+    yAxisLabel1 <- sub(paste0(C_PARAMETER_NAMES[["futilityBoundsDelayedInformation"]], " and"),
+        "Lower and", yAxisLabel1,
+        fixed = TRUE
+    )
+    yAxisLabel1 <- sub(paste0(C_PARAMETER_NAMES[["futilityBoundsDelayedInformationNonBinding"]], " and"),
+        "Lower and", yAxisLabel1,
+        fixed = TRUE
+    )
+    
     if (!("xValues" %in% colnames(data)) || !("yValues" %in% colnames(data))) {
+        if (!(xParameterName %in% colnames(data))) {
+            stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, sQuote(xParameterName), " is not available in dataset")
+        }
+        if (!(yParameterName1 %in% colnames(data))) {
+            stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, sQuote(yParameterName1), " is not available in dataset")
+        }
+
         data$xValues <- data[[xParameterName]]
         data$yValues <- data[[yParameterName1]]
         if (yParameterName1 == "futilityBounds") {
@@ -972,11 +1008,17 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
         if (is.null(yParameterName2) || is.na(yParameterName2)) {
             data$yValues2 <- rep(NA_real_, nrow(data))
         } else {
+            if (!(yParameterName2 %in% colnames(data))) {
+                stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, sQuote(yParameterName2), " is not available in dataset")
+            }
             data$yValues2 <- data[[yParameterName2]]
         }
         if (is.null(yParameterName3)) {
             data$yValues3 <- rep(NA_real_, nrow(data))
         } else {
+            if (!(yParameterName3 %in% colnames(data))) {
+                stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, sQuote(yParameterName3), " is not available in dataset")
+            }
             data$yValues3 <- data[[yParameterName3]]
         }
 
@@ -992,7 +1034,7 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
             data$categories <- rep(NA_character_, nrow(data))
         }
     }
-
+    
     if (!is.na(nMax) && is.null(yParameterName3) && xParameterName == "informationRates") {
         xAxisLabel <- "Sample Size"
         data$xValues <- data$xValues * nMax
@@ -1017,7 +1059,7 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
             categories = uc
         ), data)
     }
-    
+
     scalingFactor1 <- 1
     scalingFactor2 <- 1
     if (!is.null(yParameterName2) && "yValues2" %in% colnames(data) && "yValues3" %in% colnames(data)) {
@@ -1042,7 +1084,7 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
                 categories = .getCategories(data, yParameterName2, tableColumnNames)
             )
         }
-        if (!is.null(yParameterName3)) {           
+        if (!is.null(yParameterName3)) {
             df3 <- data.frame(
                 xValues = data$xValues,
                 yValues = data$yValues3 * scalingFactor2,
@@ -1067,7 +1109,7 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
             legendTitle <- paste(legendTitle, "Type of error", sep = sep)
         }
     }
-
+    
     if (is.na(legendPosition)) {
         legendPosition <- .getLegendPosition(
             plotSettings, designMaster, data, yParameterName1,
@@ -1080,7 +1122,7 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
             (.isTrialDesignPlanMeans(parameterSet) && parameterSet$meanRatio) ||
             (.isTrialDesignPlanRates(parameterSet) && parameterSet$riskRatio)
     }
-    
+
     plotDashedHorizontalLine <- "criticalValuesEffectScale" %in% yParameterNames && designMaster$sided == 2
     p <- .plotDataFrame(data,
         mainTitle = mainTitle, xlab = xlab, ylab = ylab,
@@ -1248,7 +1290,7 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
 
     data$yValues[!is.na(data$yValues) & is.infinite(data$yValues)] <- NA_real_
     data <- data[!is.na(data$yValues), ]
-
+    
     if (categoryEnabled && groupEnabled) {
         p <- ggplot2::ggplot(data, ggplot2::aes(
             x = .data[["xValues"]], y = .data[["yValues"]],
