@@ -13,9 +13,9 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6522 $
-## |  Last changed: $Date: 2022-08-23 17:43:29 +0200 (Di, 23 Aug 2022) $
-## |  Last changed by: $Author: wassmer $
+## |  File version: $Revision: 7408 $
+## |  Last changed: $Date: 2023-11-09 10:36:19 +0100 (Do, 09 Nov 2023) $
+## |  Last changed by: $Author: pahlke $
 ## |
 
 #' @include f_core_constants.R
@@ -25,7 +25,7 @@ NULL
 
 .getFisherCombinationSize <- function(kMax, alpha0Vec, criticalValues, tVec,
         cases = .getFisherCombinationCases(kMax = kMax, tVec = tVec)) {
-    return(getFisherCombinationSizeCpp(kMax, alpha0Vec, criticalValues, tVec, cases))
+    return(.getFisherCombinationSizeCpp(kMax, alpha0Vec, criticalValues, tVec, cases))
 }
 
 #' @title
@@ -52,11 +52,11 @@ NULL
 #' @inheritParams param_three_dots
 #'
 #' @details
-#' \code{getDesignFisher} calculates the critical values and stage levels for
+#' \code{getDesignFisher()} calculates the critical values and stage levels for
 #' Fisher's combination test as described in Bauer (1989), Bauer and Koehne (1994),
 #' Bauer and Roehmel (1995), and Wassmer (1999) for equally and unequally sized stages.
 #'
-#' @seealso \code{\link{getDesignSet}} for creating a set of designs to compare.
+#' @seealso \code{\link[=getDesignSet]{getDesignSet()}} for creating a set of designs to compare.
 #'
 #' @template return_object_trial_design
 #' @template how_to_get_help_for_generics
@@ -81,12 +81,7 @@ getDesignFisher <- function(...,
         seed = NA_real_) {
     .assertIsValidTolerance(tolerance)
     .assertIsValidIterationsAndSeed(iterations, seed)
-    .warnInCaseOfUnknownArguments(functionName = "getDesignFisher", ignore = c("cppEnabled"), ...)
-
-    cppEnabled <- .getOptionalArgument("cppEnabled", ..., optionalArgumentDefaultValue = TRUE)
-    if (!cppEnabled) {
-        stop("The cppEnabled option of  getDesignFisher() is deprecated and no longer available in rpact")
-    }
+    .warnInCaseOfUnknownArguments(functionName = "getDesignFisher", ...)
 
     return(.getDesignFisher(
         kMax = kMax, alpha = alpha, method = method,
@@ -112,13 +107,11 @@ getDesignFisher <- function(...,
     ))
 }
 
-.getFisherCombinationCases <- function(kMax, tVec) {
-    return(getFisherCombinationCasesCpp(kMax, tVec))
-}
-
-#
-# @param userFunctionCallEnabled if \code{TRUE}, additional parameter validation methods will be called.
-#
+#'
+#' @param userFunctionCallEnabled if \code{TRUE}, additional parameter validation methods will be called.
+#'
+#' @noRd
+#'
 .getDesignFisher <- function(kMax = NA_integer_, alpha = NA_real_, method = C_FISHER_METHOD_DEFAULT,
         userAlphaSpending = NA_real_, alpha0Vec = NA_real_, informationRates = NA_real_,
         sided = 1, bindingFutility = C_BINDING_FUTILITY_FISHER_DEFAULT,
@@ -260,9 +253,10 @@ getDesignFisher <- function(...,
     tryCatch(
         {
             cases <- .getFisherCombinationCases(kMax = design$kMax, tVec = design$scale)
-            result <- getDesignFisherTryCpp(
+            result <- .getDesignFisherInner(
                 design$kMax, design$alpha, design$tolerance,
-                design$criticalValues, design$scale, alpha0Vec, design$userAlphaSpending, design$method
+                design$criticalValues, design$scale, alpha0Vec, 
+                design$userAlphaSpending, design$method
             )
             design$criticalValues <- result$criticalValues
             design$alphaSpent <- result$alphaSpent
@@ -326,9 +320,11 @@ getDesignFisher <- function(...,
         if (design$kMax > 1) {
             diff <- na.omit(design$criticalValues[2:design$kMax] - design$criticalValues[1:(design$kMax - 1)])
             if (length(diff) > 0 && any(diff > 1e-12)) {
-                .logDebug("Stop creation of Fisher design because critical values are ", 
+                .logDebug(
+                    "Stop creation of Fisher design because critical values are ",
                     .arrayToString(criticalValues, vectorLookAndFeelEnabled = TRUE), ", ",
-                    "i.e., differences are ", .arrayToString(diff, vectorLookAndFeelEnabled = TRUE))
+                    "i.e., differences are ", .arrayToString(diff, vectorLookAndFeelEnabled = TRUE)
+                )
                 stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, "no calculation possible")
             }
 
@@ -358,7 +354,7 @@ getDesignFisher <- function(...,
             C_PARAM_USER_DEFINED, C_PARAM_DEFAULT_VALUE
         ))
         design$seed <- .setSeed(design$seed)
-        design$simAlpha <- getSimulatedAlphaCpp(
+        design$simAlpha <- .getSimulatedAlphaCpp(
             kMax = design$kMax,
             alpha0 = design$alpha0Vec,
             criticalValues = design$criticalValues,
