@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6497 $
-## |  Last changed: $Date: 2022-08-17 13:32:36 +0200 (Wed, 17 Aug 2022) $
+## |  File version: $Revision: 7428 $
+## |  Last changed: $Date: 2023-11-13 10:42:22 +0100 (Mo, 13 Nov 2023) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -35,6 +35,12 @@ NULL
     }
 }
 
+.skipTestIfPipeOperatorNotAvailable <- function() {
+    if (!.isPipeOperatorAvailable()) {
+        testthat::skip("The test is disabled because it works only for R version >= 4.1.0 (pipe operator is available)")
+    }
+}
+
 .isMachine64Bit <- function() {
     return(Sys.info()[["machine"]] == "x86-64")
 }
@@ -43,6 +49,11 @@ NULL
     return(R.Version()$major >= 4)
 }
 
+.isPipeOperatorAvailable <- function() {
+    rVersion <- R.Version()
+    return(rVersion$major >= 4 && rVersion$minor >= "1.0")
+}
+
 .getTestthatResultLine <- function(fileContent) {
     if (grepl("\\[ OK:", fileContent)) {
         indexStart <- regexpr("\\[ OK: \\d", fileContent)[[1]]
@@ -448,8 +459,8 @@ testPackage <- function(outDir = ".", ...,
         types = "tests",
         connection = list(token = NULL, secret = NULL)) {
     .assertTestthatIsInstalled()
-    .assertMnormtIsInstalled()
 
+    .assertIsSingleCharacter(outDir, "outDir", naAllowed = FALSE)
     if (!dir.exists(outDir)) {
         stop(
             C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
@@ -613,6 +624,7 @@ testPackage <- function(outDir = ".", ...,
 }
 
 .testInstalledPackage <- function(testFileDirectory, ..., pkgName = "rpact", outDir = ".", Ropts = "") {
+    .assertIsSingleCharacter(testFileDirectory, "testFileDirectory", naAllowed = FALSE)
     if (!dir.exists(testFileDirectory)) {
         stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'testFileDirectory' (", testFileDirectory, ") does not exist")
     }
@@ -640,11 +652,12 @@ testPackage <- function(outDir = ".", ...,
 
         savefile <- paste(outfile, "save", sep = ".")
         if (file.exists(savefile)) {
-            message(gettextf(
-                "  comparing %s to %s ...",
-                sQuote(outfile), sQuote(savefile)
-            ),
-            appendLF = FALSE, domain = NA
+            message(
+                gettextf(
+                    "  comparing %s to %s ...",
+                    sQuote(outfile), sQuote(savefile)
+                ),
+                appendLF = FALSE, domain = NA
             )
             res <- Rdiff(outfile, savefile)
             if (!res) message(" OK")
@@ -664,20 +677,20 @@ testPackage <- function(outDir = ".", ...,
     return(isTRUE(completeUnitTestSetEnabled))
 }
 
-#' 
-#' @title 
+#'
+#' @title
 #' Test Plan Section
-#' 
+#'
 #' @param section The section title or description.
-#' 
-#' @description 
-#' The section title or description will be used in the formal validation documentation. 
+#'
+#' @description
+#' The section title or description will be used in the formal validation documentation.
 #' For more information visit \url{https://www.rpact.com}
-#' 
-#' @export 
-#' 
+#'
+#' @export
+#'
 #' @keywords internal
-#' 
+#'
 test_plan_section <- function(section) {
-    cat("--- ", section, " ---\n", sep = "")
+    cat("\n\n--- ", section, " ---\n", sep = "")
 }
