@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6585 $
-## |  Last changed: $Date: 2022-09-23 14:23:08 +0200 (Fr, 23 Sep 2022) $
+## |  File version: $Revision: 7547 $
+## |  Last changed: $Date: 2024-01-10 08:13:40 +0100 (Mi, 10 Jan 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -22,6 +22,18 @@
 #' @include f_core_utilities.R
 NULL
 
+.warnInCaseOfDefinedPiValue <- function(designPlan, piValueName) {
+    piValue <- designPlan[[piValueName]]
+    if (!is.null(piValue) && !is.na(piValue) && length(piValue) > 0) {
+        designPlan$.setParameterType(piValueName, C_PARAM_NOT_APPLICABLE)
+        warning("'pi2' (", .arrayToString(piValue), ") will be ignored ",
+            "because piecewise exponential survival function is enabled",
+            call. = FALSE
+        )
+        designPlan[[piValueName]] <- NA_real_
+    }
+}
+
 .isLambdaBasedSimulationEnabled <- function(pwsTimeObject) {
     if (!pwsTimeObject$.isLambdaBased()) {
         return(FALSE)
@@ -108,6 +120,7 @@ NULL
 #' @inheritParams param_conditionalPowerSimulation
 #' @inheritParams param_thetaH1
 #' @inheritParams param_maxNumberOfIterations
+#' @inheritParams param_calcEventsFunction
 #' @inheritParams param_showStatistics
 #' @param maxNumberOfRawDatasetsPerStage The number of raw datasets per stage that shall
 #'        be extracted and saved as \code{\link[base]{data.frame}}, default is \code{0}.
@@ -125,11 +138,11 @@ NULL
 #' and constant or non-constant piecewise accrual).
 #' Additionally, integers \code{allocation1} and \code{allocation2} can be specified that determine the number allocated
 #' to treatment group 1 and treatment group 2, respectively.
-#' More precisely, unequal randomization ratios must be specified via the two integer arguments \code{allocation1} and 
-#' \code{allocation2} which describe how many subjects are consecutively enrolled in each group, respectively, before a 
-#' subject is assigned to the other group. For example, the arguments \code{allocation1 = 2}, \code{allocation2 = 1}, 
-#' \code{maxNumberOfSubjects = 300} specify 2:1 randomization with 200 subjects randomized to intervention and 100 to 
-#' control. (Caveat: Do not use \code{allocation1 = 200}, \code{allocation2 = 100}, \code{maxNumberOfSubjects = 300} 
+#' More precisely, unequal randomization ratios must be specified via the two integer arguments \code{allocation1} and
+#' \code{allocation2} which describe how many subjects are consecutively enrolled in each group, respectively, before a
+#' subject is assigned to the other group. For example, the arguments \code{allocation1 = 2}, \code{allocation2 = 1},
+#' \code{maxNumberOfSubjects = 300} specify 2:1 randomization with 200 subjects randomized to intervention and 100 to
+#' control. (Caveat: Do not use \code{allocation1 = 200}, \code{allocation2 = 100}, \code{maxNumberOfSubjects = 300}
 #' as this would imply that the 200 intervention subjects are enrolled prior to enrollment of any control subjects.)
 #'
 #' \code{conditionalPower}\cr
@@ -138,7 +151,21 @@ NULL
 #' \code{maxNumberOfEventsPerStage} are defined.
 #'
 #' Note that \code{numberOfSubjects}, \code{numberOfSubjects1}, and \code{numberOfSubjects2} in the output
-#' are expected number of subjects.
+#' are the expected number of subjects.
+#'
+#' \code{calcEventsFunction}\cr
+#' This function returns the number of events at given conditional power and conditional critical value for specified
+#' testing situation. The function might depend on variables
+#' \code{stage},
+#' \code{conditionalPower},
+#' \code{thetaH0},
+#' \code{plannedEvents},
+#' \code{eventsPerStage},
+#' \code{minNumberOfEventsPerStage},
+#' \code{maxNumberOfEventsPerStage},
+#' \code{allocationRatioPlanned},
+#' \code{conditionalCriticalValue},
+#' The function has to contain the three-dots argument '...' (see examples).
 #'
 #' @template details_piecewise_survival
 #'
@@ -197,27 +224,6 @@ NULL
 #' \code{\link[=getRawData]{getRawData()}} can be used to get the simulated raw data from the
 #' object as \code{\link[base]{data.frame}}. Note that \code{getSimulationSurvival()}
 #' must called before with \code{maxNumberOfRawDatasetsPerStage} > 0.
-#' The data frame contains the following columns:
-#' \enumerate{
-#'   \item \code{iterationNumber}: The number of the simulation iteration.
-#'   \item \code{stopStage}: The stage of stopping.
-#'   \item \code{subjectId}: The subject id (increasing number 1, 2, 3, ...)
-#'   \item \code{accrualTime}: The accrual time, i.e., the time when the subject entered the trial.
-#'   \item \code{treatmentGroup}: The treatment group number (1 or 2).
-#'   \item \code{survivalTime}: The survival time of the subject.
-#'   \item \code{dropoutTime}: The dropout time of the subject (may be \code{NA}).
-#'   \item \code{observationTime}: The specific observation time.
-#'   \item \code{timeUnderObservation}: The time under observation is defined as follows:\cr
-#'         if (event == TRUE) {\cr
-#'             timeUnderObservation <- survivalTime;\cr
-#'         } else if (dropoutEvent == TRUE) {\cr
-#'             timeUnderObservation <- dropoutTime;\cr
-#'         } else {\cr
-#'             timeUnderObservation <- observationTime - accrualTime;\cr
-#'         }
-#'   \item \code{event}: \code{TRUE} if an event occurred; \code{FALSE} otherwise.
-#'   \item \code{dropoutEvent}: \code{TRUE} if an dropout event occurred; \code{FALSE} otherwise.
-#' }
 #'
 #' @template return_object_simulation_results
 #' @template how_to_get_help_for_generics
@@ -257,6 +263,7 @@ getSimulationSurvival <- function(design = NULL, ...,
         maxNumberOfRawDatasetsPerStage = 0,
         longTimeSimulationAllowed = FALSE,
         seed = NA_real_,
+        calcEventsFunction = NULL,
         showStatistics = FALSE) {
     .assertRcppIsInstalled()
 
@@ -291,13 +298,14 @@ getSimulationSurvival <- function(design = NULL, ...,
     .assertIsSingleNumber(seed, "seed", naAllowed = TRUE)
     .assertIsNumericVector(lambda1, "lambda1", naAllowed = TRUE)
     .assertIsNumericVector(lambda2, "lambda2", naAllowed = TRUE)
-    .assertIsSinglePositiveInteger(maxNumberOfSubjects, "maxNumberOfSubjects",
-        validateType = FALSE, naAllowed = TRUE
-    )
-    .assertIsSinglePositiveInteger(allocation1, "allocation1", validateType = FALSE)
-    .assertIsSinglePositiveInteger(allocation2, "allocation2", validateType = FALSE)
+    .assertIsValidMaxNumberOfSubjects(maxNumberOfSubjects, naAllowed = TRUE)    
+    .assertIsIntegerVector(allocation1, "allocation1", validateType = FALSE)
+    .assertIsIntegerVector(allocation2, "allocation2", validateType = FALSE)
+    .assertIsInClosedInterval(allocation1, "allocation1", lower = 1L, upper = NULL)
+    .assertIsInClosedInterval(allocation2, "allocation2", lower = 1L, upper = NULL)
     .assertIsSingleLogical(longTimeSimulationAllowed, "longTimeSimulationAllowed")
     .assertIsSingleLogical(showStatistics, "showStatistics", naAllowed = FALSE)
+    .assertIsValidPlannedSubjectsOrEvents(design, plannedEvents, parameterName = "plannedEvents")
 
     if (design$sided == 2) {
         stop(
@@ -434,15 +442,6 @@ getSimulationSurvival <- function(design = NULL, ...,
         accrualSetup$.getParameterType("accrualIntensity")
     )
 
-    .assertIsIntegerVector(plannedEvents, "plannedEvents", validateType = FALSE)
-    if (length(plannedEvents) != design$kMax) {
-        stop(
-            C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
-            "'plannedEvents' (", .arrayToString(plannedEvents), ") must have length ", design$kMax
-        )
-    }
-    .assertIsInClosedInterval(plannedEvents, "plannedEvents", lower = 1, upper = NULL)
-    .assertValuesAreStrictlyIncreasing(plannedEvents, "plannedEvents")
     simulationResults$plannedEvents <- plannedEvents
     simulationResults$.setParameterType("plannedEvents", C_PARAM_USER_DEFINED)
 
@@ -566,8 +565,20 @@ getSimulationSurvival <- function(design = NULL, ...,
     .setValueAndParameterType(simulationResults, "dropoutRate2", dropoutRate2, C_DROP_OUT_RATE_2_DEFAULT)
     .setValueAndParameterType(simulationResults, "dropoutTime", dropoutTime, C_DROP_OUT_TIME_DEFAULT)
     .setValueAndParameterType(simulationResults, "thetaH0", thetaH0, C_THETA_H0_SURVIVAL_DEFAULT)
+
+    allocationFraction <- getFraction(allocation1 / allocation2)
+    if (allocationFraction[1] != allocation1 || allocationFraction[2] != allocation2) {
+        warning(sprintf(
+            "allocation1 = %s and allocation2 = %s was replaced by allocation1 = %s and allocation2 = %s",
+            allocation1, allocation2, allocationFraction[1], allocationFraction[2]
+        ), call. = FALSE)
+        allocation1 <- allocationFraction[1]
+        allocation2 <- allocationFraction[2]
+    }
+
     .setValueAndParameterType(simulationResults, "allocation1", allocation1, C_ALLOCATION_1_DEFAULT)
     .setValueAndParameterType(simulationResults, "allocation2", allocation2, C_ALLOCATION_2_DEFAULT)
+
     allocationRatioPlanned <- allocation1 / allocation2
     .setValueAndParameterType(
         simulationResults, "allocationRatioPlanned",
@@ -611,14 +622,16 @@ getSimulationSurvival <- function(design = NULL, ...,
             intensityReplications[1]
         ))
         if (length(accrualIntensity) > 1 && length(intensityReplications) > 1) {
-            for (i in 2:min(length(accrualIntensity), length(intensityReplications))) { 
+            for (i in 2:min(length(accrualIntensity), length(intensityReplications))) {
                 if (intensityReplications[i] > 0) {
-                    accrualTimeValue <- c(accrualTimeValue, 
+                    accrualTimeValue <- c(
+                        accrualTimeValue,
                         accrualTime[i - 1] +
-                        cumsum(rep(
-                            1 / (densityVector[i] * accrualSetup$maxNumberOfSubjects),
-                            intensityReplications[i]
-                        )))
+                            cumsum(rep(
+                                1 / (densityVector[i] * accrualSetup$maxNumberOfSubjects),
+                                intensityReplications[i]
+                            ))
+                    )
                 }
             }
         }
@@ -655,7 +668,28 @@ getSimulationSurvival <- function(design = NULL, ...,
         designNumber <- 3L
     }
 
-    resultData <- getSimulationSurvivalCpp(
+    calcSubjectsFunctionList <- .getCalcSubjectsFunction(
+        design = design,
+        simulationResults = simulationResults,
+        calcFunction = calcEventsFunction,
+        expectedFunction = function(stage,
+                conditionalPower,
+                thetaH0,
+                estimatedTheta,
+                plannedEvents,
+                eventsOverStages,
+                minNumberOfEventsPerStage,
+                maxNumberOfEventsPerStage,
+                allocationRatioPlanned,
+                conditionalCriticalValue) {
+            NULL
+        }
+    )
+    calcEventsFunctionType <- calcSubjectsFunctionList$calcSubjectsFunctionType
+    calcEventsFunctionR <- calcSubjectsFunctionList$calcSubjectsFunctionR
+    calcEventsFunctionCpp <- calcSubjectsFunctionList$calcSubjectsFunctionCpp
+
+    resultData <- .getSimulationSurvivalCpp(
         designNumber                   = designNumber,
         kMax                           = design$kMax,
         sided                          = design$sided,
@@ -667,8 +701,7 @@ getSimulationSurvival <- function(design = NULL, ...,
         minNumberOfEventsPerStage      = minNumberOfEventsPerStage,
         maxNumberOfEventsPerStage      = maxNumberOfEventsPerStage,
         directionUpper                 = directionUpper,
-        allocation1                    = allocation1,
-        allocation2                    = allocation2,
+        allocationRatioPlanned         = allocationRatioPlanned,
         accrualTime                    = accrualTimeValue,
         treatmentGroup                 = treatmentGroup,
         thetaH0                        = thetaH0,
@@ -686,7 +719,10 @@ getSimulationSurvival <- function(design = NULL, ...,
         maxNumberOfSubjects            = accrualSetup$maxNumberOfSubjects,
         maxNumberOfIterations          = maxNumberOfIterations,
         maxNumberOfRawDatasetsPerStage = maxNumberOfRawDatasetsPerStage,
-        kappa                          = kappa
+        kappa                          = kappa,
+        calcEventsFunctionType         = calcEventsFunctionType,
+        calcEventsFunctionR            = calcEventsFunctionR,
+        calcEventsFunctionCpp          = calcEventsFunctionCpp
     )
 
     overview <- resultData$overview
@@ -725,7 +761,7 @@ getSimulationSurvival <- function(design = NULL, ...,
         .getNumberOfSubjects1(simulationResults$numberOfSubjects, allocationRatioPlanned)
     simulationResults$numberOfSubjects2 <-
         .getNumberOfSubjects2(simulationResults$numberOfSubjects, allocationRatioPlanned)
-    if (allocationRatioPlanned != 1) {
+    if (any(allocationRatioPlanned != 1)) {
         simulationResults$.setParameterType("numberOfSubjects1", C_PARAM_GENERATED)
         simulationResults$.setParameterType("numberOfSubjects2", C_PARAM_GENERATED)
     }
@@ -757,11 +793,12 @@ getSimulationSurvival <- function(design = NULL, ...,
                 nrow = design$kMax - 1
             )
         } else {
-            simulationResults$futilityPerStage <- matrix(matrix(
-                overview$futilityPerStage,
-                nrow = design$kMax
-            )[1:(design$kMax - 1), ],
-            nrow = design$kMax - 1
+            simulationResults$futilityPerStage <- matrix(
+                matrix(
+                    overview$futilityPerStage,
+                    nrow = design$kMax
+                )[1:(design$kMax - 1), ],
+                nrow = design$kMax - 1
             )
         }
     }
@@ -789,7 +826,7 @@ getSimulationSurvival <- function(design = NULL, ...,
         if (!is.null(simulationResults$eventsPerStage) &&
                 nrow(simulationResults$eventsPerStage) > 0 &&
                 ncol(simulationResults$eventsPerStage) > 0) {
-			simulationResults$overallEventsPerStage <- .convertStageWiseToOverallValues(
+            simulationResults$overallEventsPerStage <- .convertStageWiseToOverallValues(
                 simulationResults$eventsPerStage
             )
             simulationResults$.setParameterType("overallEventsPerStage", C_PARAM_GENERATED)
@@ -802,7 +839,7 @@ getSimulationSurvival <- function(design = NULL, ...,
         if (!is.null(simulationResults$eventsPerStage) &&
                 nrow(simulationResults$eventsPerStage) > 0 &&
                 ncol(simulationResults$eventsPerStage) > 0) {
-			simulationResults$overallEventsPerStage <- simulationResults$eventsPerStage
+            simulationResults$overallEventsPerStage <- simulationResults$eventsPerStage
             simulationResults$expectedNumberOfEvents <-
                 as.numeric(simulationResults$overallEventsPerStage)
         }
@@ -820,10 +857,9 @@ getSimulationSurvival <- function(design = NULL, ...,
         rawData <- rawData[!is.na(rawData$iterationNumber), ]
     }
     if (!is.null(rawData) && nrow(rawData) > 0 && ncol(rawData) > 0) {
-        
-        rawData <- rawData[order(rawData$iterationNumber, rawData$subjectId),]
+        rawData <- rawData[order(rawData$iterationNumber, rawData$subjectId), ]
         rownames(rawData) <- NULL
-        
+
         stopStageNumbers <- rawData$stopStage
         missingStageNumbers <- c()
         if (length(stopStageNumbers) > 0) {
