@@ -13,54 +13,56 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6708 $
-## |  Last changed: $Date: 2022-12-02 08:50:56 +0100 (Fr, 02 Dez 2022) $
+## |  File version: $Revision: 7547 $
+## |  Last changed: $Date: 2024-01-10 08:13:40 +0100 (Mi, 10 Jan 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
 #' @include f_core_utilities.R
 NULL
 
-#
-# @title
-# Set Seed
-#
-# @description
-# Sets the seed, generates it if \code{is.na(seed) == TRUE} and returns it.
-#
-# @param seed the seed to set.
-#
-# @details
-# Internal function.
-#
-# @return the (generated) seed.
-#
-# @examples
-#
-# .setSeed(12345)
-#
-# mySeed <- .setSeed()
-#
-# @keywords internal
-#
+#'
+#' @title
+#' Set Seed
+#'
+#' @description
+#' Sets the seed, generates it if \code{is.na(seed) == TRUE} and returns it.
+#'
+#' @param seed the seed to set.
+#'
+#' @details
+#' Internal function.
+#'
+#' @return the (generated) seed.
+#'
+#' @examples
+#'
+#' .setSeed(12345)
+#'
+#' mySeed <- .setSeed()
+#'
+#' @keywords internal
+#'
+#' @noRd
+#'
 .setSeed <- function(seed = NA_real_) {
     if (!is.null(seed) && !is.na(seed)) {
         if (is.na(as.integer(seed))) {
             stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'seed' must be a valid integer")
         }
-        
+
         set.seed(seed = seed, kind = "Mersenne-Twister", normal.kind = "Inversion")
         return(seed)
     }
-    
+
     if (exists(".Random.seed") && length(.Random.seed) > 0) {
         seed <- .Random.seed[length(.Random.seed)]
     } else {
         seed <- round(stats::runif(1) * 1e8)
     }
-    
+
     .logDebug("Set seed to %s", seed)
-    
+
     tryCatch(
         {
             set.seed(seed, kind = "Mersenne-Twister", normal.kind = "Inversion")
@@ -71,7 +73,7 @@ NULL
             traceback()
         }
     )
-    
+
     invisible(seed)
 }
 
@@ -89,19 +91,18 @@ NULL
 }
 
 .getSimulationParametersFromRawData <- function(data, ..., variantName, maxNumberOfIterations = NA_integer_) {
-    
     if (is.null(data) || length(data) != 1) {
         stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'data' must be a valid data.frame or a simulation result object")
     }
-        
+
     if (inherits(data, "SimulationResults")) {
         data <- data[[".data"]]
     }
-        
+
     if (!is.data.frame(data)) {
         stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'data' (", .getClassName(data), ") must be a data.frame or a simulation result object")
     }
-    
+
     if (is.na(maxNumberOfIterations)) {
         maxNumberOfIterations <- max(data$iterationNumber)
     }
@@ -195,12 +196,11 @@ C_EFFECT_LIST_NAMES_EXPECTED_MEANS <- c("subGroups", "prevalences", "effects", "
 C_EFFECT_LIST_NAMES_EXPECTED_RATES <- c("subGroups", "prevalences", "piControls", "piTreatments")
 C_EFFECT_LIST_NAMES_EXPECTED_SURVIVAL <- c("subGroups", "prevalences", "piControls", "hazardRatios")
 
-.getEffectData <- function(effectList, ..., 
-        endpoint = NA_character_, 
-        gMax = NA_integer_, 
+.getEffectData <- function(effectList, ...,
+        endpoint = NA_character_,
+        gMax = NA_integer_,
         nullAllowed = TRUE,
         parameterNameWarningsEnabled = TRUE) {
-        
     if (nullAllowed && is.null(effectList)) {
         return(NULL)
     }
@@ -255,13 +255,13 @@ C_EFFECT_LIST_NAMES_EXPECTED_SURVIVAL <- c("subGroups", "prevalences", "piContro
         }
         if ("F" %in% subGroups) {
             stop(
-                C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "definition of full population 'F' ", 
+                C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "definition of full population 'F' ",
                 "together with sub-groups", ifelse(length(subGroups) == 2, "", "s"), " ",
-                .arrayToString(subGroups[subGroups != "F"], encapsulate = TRUE, mode = "and"), 
+                .arrayToString(subGroups[subGroups != "F"], encapsulate = TRUE, mode = "and"),
                 " makes no sense and is not allowed (use remaining population 'R' instead of 'F')"
             )
         }
-        expectedSubGroups <- .createSubsetsByGMax(gMax, stratifiedInput = TRUE, all = FALSE) 
+        expectedSubGroups <- .createSubsetsByGMax(gMax, stratifiedInput = TRUE, all = FALSE)
         if (gMax < 3) {
             expectedSubGroups <- gsub("\\d", "", expectedSubGroups)
         }
@@ -286,26 +286,24 @@ C_EFFECT_LIST_NAMES_EXPECTED_SURVIVAL <- c("subGroups", "prevalences", "piContro
 
     matrixName <- NA_character_
     matrixNames <- c("effects", "piTreatments", "hazardRatios")
-    
+
     if (!is.na(endpoint)) {
         if (endpoint == "means") {
             matrixNames <- "effects"
-        }
-        else if (endpoint == "rates") {
+        } else if (endpoint == "rates") {
             matrixNames <- "piTreatments"
-        }
-        else if (endpoint == "survival") {
+        } else if (endpoint == "survival") {
             matrixNames <- "hazardRatios"
         }
     }
-    
+
     for (m in matrixNames) {
         if (m %in% effectListNames) {
             matrixName <- m
             break
         }
     }
-    
+
     if (is.na(matrixName)) {
         stop(
             C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, sQuote("effectList"), " must contain ",
@@ -418,20 +416,20 @@ C_EFFECT_LIST_NAMES_EXPECTED_SURVIVAL <- c("subGroups", "prevalences", "piContro
     }
 
     longData <- longData[, colnames(longData) != "subGroupNumber"]
-    
+
     if (parameterNameWarningsEnabled && !is.na(endpoint)) {
         if (endpoint == "means") {
             ignore <- effectListNames[!(effectListNames %in% C_EFFECT_LIST_NAMES_EXPECTED_MEANS)]
-        }
-        else if (endpoint == "rates") {
+        } else if (endpoint == "rates") {
             ignore <- effectListNames[!(effectListNames %in% C_EFFECT_LIST_NAMES_EXPECTED_RATES)]
-        }
-        else if (endpoint == "survival") {
+        } else if (endpoint == "survival") {
             ignore <- effectListNames[!(effectListNames %in% C_EFFECT_LIST_NAMES_EXPECTED_SURVIVAL)]
         }
         if (length(ignore) > 0) {
             warning("The parameter", ifelse(length(ignore) == 1, "", "s"), " ", .arrayToString(ignore, encapsulate = TRUE),
-                " will be ignored", call. = FALSE)
+                " will be ignored",
+                call. = FALSE
+            )
         }
     }
 
@@ -491,11 +489,10 @@ C_EFFECT_LIST_NAMES_EXPECTED_SURVIVAL <- c("subGroups", "prevalences", "piContro
     ))
 }
 
-.getEffectList <- function(effectData, ..., 
-        parameterName = "effectData", 
+.getEffectList <- function(effectData, ...,
+        parameterName = "effectData",
         endpoint = NA_character_,
         parameterNameWarningsEnabled = TRUE) {
-        
     if (is.null(effectData) || length(effectData) == 0 || !is.data.frame(effectData)) {
         stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, sQuote(parameterName), " must be a non-empty data.frame")
     }
@@ -515,9 +512,10 @@ C_EFFECT_LIST_NAMES_EXPECTED_SURVIVAL <- c("subGroups", "prevalences", "piContro
     if (is.na(matrixName)) {
         stop(
             C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, sQuote(parameterName), " must contain ",
-            ifelse(!is.na(expectedMatrixName), 
-                sQuote(expectedMatrixName), 
-                .arrayToString(matrixNames, mode = "or", encapsulate = TRUE))
+            ifelse(!is.na(expectedMatrixName),
+                sQuote(expectedMatrixName),
+                .arrayToString(matrixNames, mode = "or", encapsulate = TRUE)
+            )
         )
     }
 
@@ -552,26 +550,27 @@ C_EFFECT_LIST_NAMES_EXPECTED_SURVIVAL <- c("subGroups", "prevalences", "piContro
     if (!is.matrix(effectList[[matrixNameNew]])) {
         effectList[[matrixNameNew]] <- matrix(effectList[[matrixNameNew]], ncol = 1)
     }
-    
+
     if (parameterNameWarningsEnabled && !is.na(endpoint)) {
         if (endpoint == "means") {
             ignore <- effectDataNames[!(effectDataNames %in% gsub("s$", "", C_EFFECT_LIST_NAMES_EXPECTED_MEANS))]
-        }
-        else if (endpoint == "rates") {
+        } else if (endpoint == "rates") {
             ignore <- effectDataNames[!(effectDataNames %in% gsub("s$", "", C_EFFECT_LIST_NAMES_EXPECTED_RATES))]
-        }
-        else if (endpoint == "survival") {
+        } else if (endpoint == "survival") {
             ignore <- effectDataNames[!(effectDataNames %in% gsub("s$", "", C_EFFECT_LIST_NAMES_EXPECTED_SURVIVAL))]
         }
         if (length(ignore) > 0) {
             warning("The parameter", ifelse(length(ignore) == 1, "", "s"), " ", .arrayToString(ignore, encapsulate = TRUE),
-                " will be ignored", call. = FALSE)
+                " will be ignored",
+                call. = FALSE
+            )
         }
     }
-    
+
     if (!is.null(effectList[["prevalences"]])) {
-        .assertIsInClosedInterval(effectList$prevalences, "effectList$prevalences", 
-            lower = 0, upper = 1, call. = FALSE)
+        .assertIsInClosedInterval(effectList$prevalences, "effectList$prevalences",
+            lower = 0, upper = 1, call. = FALSE
+        )
     }
     if (!is.null(effectList[["effects"]])) {
         .assertIsNumericVector(effectList$effects, "effectList$effects", call. = FALSE)
@@ -580,22 +579,25 @@ C_EFFECT_LIST_NAMES_EXPECTED_SURVIVAL <- c("subGroups", "prevalences", "piContro
         if (!is.null(effectList[[piParam]])) {
             if (piParam == matrixNameNew && is.matrix(effectList[[piParam]])) {
                 for (i in 1:nrow(effectList[[piParam]])) {
-                    .assertIsInOpenInterval(effectList[[piParam]][i, ], paste0("effectList$", piParam), 
-                        lower = 0, upper = 1, call. = FALSE)
+                    .assertIsInOpenInterval(effectList[[piParam]][i, ], paste0("effectList$", piParam),
+                        lower = 0, upper = 1, call. = FALSE
+                    )
                 }
             } else {
-                .assertIsInOpenInterval(effectList[[piParam]], paste0("effectList$", piParam), 
-                    lower = 0, upper = 1, call. = FALSE)
+                .assertIsInOpenInterval(effectList[[piParam]], paste0("effectList$", piParam),
+                    lower = 0, upper = 1, call. = FALSE
+                )
             }
         }
     }
     for (ratioParam in c("hazardRatios", "stDevs")) {
         if (!is.null(effectList[[ratioParam]])) {
-            .assertIsInOpenInterval(effectList[[ratioParam]], paste0("effectList$", ratioParam), 
-                lower = 0, upper = NULL, call. = FALSE)
+            .assertIsInOpenInterval(effectList[[ratioParam]], paste0("effectList$", ratioParam),
+                lower = 0, upper = NULL, call. = FALSE
+            )
         }
     }
-    
+
     return(effectList)
 }
 
@@ -603,11 +605,11 @@ C_EFFECT_LIST_NAMES_EXPECTED_SURVIVAL <- c("subGroups", "prevalences", "piContro
     if (is.null(endpoint) || !(endpoint %in% c("means", "rates", "survival"))) {
         stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, "'endpoint' (", endpoint, ") must be one of 'means', 'rates', or 'survival'")
     }
-    
+
     if (is.null(effectList) || length(effectList) == 0 || (!is.list(effectList) && !is.data.frame(effectList))) {
         stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'effectList' must be a valid list or data.frame")
     }
-    
+
     if (is.data.frame(effectList)) {
         return(.getEffectList(effectList, parameterName = "effectList", endpoint = endpoint))
     }
@@ -616,4 +618,258 @@ C_EFFECT_LIST_NAMES_EXPECTED_SURVIVAL <- c("subGroups", "prevalences", "piContro
     return(.getEffectList(effectData))
 }
 
+.getVariedParameterSimulationMultiArm <- function(designPlan) {
+    if (!grepl("SimulationResultsMultiArm", .getClassName(designPlan))) {
+        stop(
+            C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'designPlan' (",
+            .getClassName(designPlan), ") must be of class 'SimulationResultsMultiArm'"
+        )
+    }
 
+    if (grepl("Means", .getClassName(designPlan))) {
+        return("muMaxVector")
+    } else if (grepl("Rates", .getClassName(designPlan))) {
+        return("piMaxVector")
+    } else if (grepl("Survival", .getClassName(designPlan))) {
+        return("omegaMaxVector")
+    }
+
+    stop(
+        C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'designPlan' (",
+        .getClassName(designPlan), ") must be of class 'SimulationResultsMultiArm'"
+    )
+}
+
+#'
+#' @title
+#' Get Simulation Data
+#'
+#' @description
+#' Returns the aggregated simulation data.
+#'
+#' @param x A \code{\link{SimulationResults}} object created by \code{\link[=getSimulationMeans]{getSimulationMeans()}},\cr
+#'  \code{\link[=getSimulationRates]{getSimulationRates()}}, \code{\link[=getSimulationSurvival]{getSimulationSurvival()}}, \code{\link[=getSimulationMultiArmMeans]{getSimulationMultiArmMeans()}},\cr
+#'  \code{\link[=getSimulationMultiArmRates]{getSimulationMultiArmRates()}}, or \code{\link[=getSimulationMultiArmSurvival]{getSimulationMultiArmSurvival()}}.
+#'
+#' @details
+#' This function can be used to get the aggregated simulated data from an simulation results
+#' object, for example, obtained by \code{\link[=getSimulationSurvival]{getSimulationSurvival()}}.
+#' In this case, the data frame contains the following columns:
+#' \enumerate{
+#'   \item \code{iterationNumber}: The number of the simulation iteration.
+#'   \item \code{stageNumber}: The stage.
+#'   \item \code{pi1}: The assumed or derived event rate in the treatment group.
+#'   \item \code{pi2}: The assumed or derived event rate in the control group.
+#'   \item \code{hazardRatio}: The hazard ratio under consideration (if available).
+#'   \item \code{analysisTime}: The analysis time.
+#'   \item \code{numberOfSubjects}: The number of subjects under consideration when the
+#'         (interim) analysis takes place.
+#'   \item \code{eventsPerStage1}: The observed number of events per stage
+#'         in treatment group 1.
+#'   \item \code{eventsPerStage2}: The observed number of events per stage
+#'         in treatment group 2.
+#'   \item \code{eventsPerStage}: The observed number of events per stage
+#'         in both treatment groups.
+#'   \item \code{rejectPerStage}: 1 if null hypothesis can be rejected, 0 otherwise.
+#'   \item \code{eventsNotAchieved}: 1 if number of events could not be reached with
+#'         observed number of subjects, 0 otherwise.
+#'   \item \code{futilityPerStage}: 1 if study should be stopped for futility, 0 otherwise.
+#'   \item \code{testStatistic}: The test statistic that is used for the test decision,
+#'         depends on which design was chosen (group sequential, inverse normal,
+#'         or Fisher combination test)'
+#'   \item \code{logRankStatistic}: Z-score statistic which corresponds to a one-sided
+#'         log-rank test at considered stage.
+#'   \item \code{conditionalPowerAchieved}: The conditional power for the subsequent stage of the trial for
+#'         selected sample size and effect. The effect is either estimated from the data or can be
+#'         user defined with \code{thetaH1} or \code{pi1H1} and \code{pi2H1}.
+#'   \item \code{trialStop}: \code{TRUE} if study should be stopped for efficacy or futility or final stage, \code{FALSE} otherwise.
+#'   \item \code{hazardRatioEstimateLR}: The estimated hazard ratio, derived from the
+#'         log-rank statistic.
+#' }
+#' A subset of variables is provided for \code{\link[=getSimulationMeans]{getSimulationMeans()}}, \code{\link[=getSimulationRates]{getSimulationRates()}}, \code{\link[=getSimulationMultiArmMeans]{getSimulationMultiArmMeans()}},\cr
+#'  \code{\link[=getSimulationMultiArmRates]{getSimulationMultiArmRates()}}, or \code{\link[=getSimulationMultiArmSurvival]{getSimulationMultiArmSurvival()}}.
+#'
+#' @template return_dataframe
+#'
+#' @examples
+#' results <- getSimulationSurvival(
+#'     pi1 = seq(0.3, 0.6, 0.1), pi2 = 0.3, eventTime = 12,
+#'     accrualTime = 24, plannedEvents = 40, maxNumberOfSubjects = 200,
+#'     maxNumberOfIterations = 50
+#' )
+#' data <- getData(results)
+#' head(data)
+#' dim(data)
+#'
+#' @export
+#'
+getData <- function(x) {
+    if (!inherits(x, "SimulationResults")) { #  or 'Dataset'
+        stop(
+            C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
+            "'x' must be a 'SimulationResults' object; for example, use getSimulationMeans() to create one"
+        )
+    }
+    
+    return(x$.data)
+}
+
+#' @rdname getData
+#' @export
+getData.SimulationResults <- function(x) {
+    return(x$.data)
+}
+
+.getAggregatedDataByIterationNumber <- function(rawData, iterationNumber, pi1 = NA_real_) {
+    if (!is.na(pi1)) {
+        if (is.null(rawData[["pi1"]])) {
+            stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, "'rawData' does not contains a 'pi1' column")
+        }
+        subData <- rawData[rawData$iterationNumber == iterationNumber & rawData$pi1 == pi1, ]
+        if (nrow(subData) == 0) {
+            return(NULL)
+        }
+    } else {
+        subData <- rawData[rawData$iterationNumber == iterationNumber, ]
+    }
+    
+    eventsPerStage1 <- sum(subData$event[subData$treatmentGroup == 1])
+    eventsPerStage2 <- sum(subData$event[subData$treatmentGroup == 2])
+    
+    result <- data.frame(
+        iterationNumber = iterationNumber,
+        pi1 = pi1,
+        stageNumber = subData$stopStage[1],
+        analysisTime = max(subData$observationTime),
+        numberOfSubjects = nrow(subData),
+        eventsPerStage1 = eventsPerStage1,
+        eventsPerStage2 = eventsPerStage2,
+        eventsPerStage = eventsPerStage1 + eventsPerStage2
+    )
+    
+    if (is.na(pi1)) {
+        result <- result[, colnames(result) != "pi1"]
+    }
+    
+    return(result)
+}
+
+.getAggregatedData <- function(rawData) {
+    iterationNumbers <- sort(unique(rawData$iterationNumber))
+    pi1Vec <- rawData[["pi1"]]
+    if (!is.null(pi1Vec)) {
+        pi1Vec <- sort(unique(na.omit(rawData$pi1)))
+    }
+    
+    data <- NULL
+    if (!is.null(pi1Vec) && length(pi1Vec) > 0) {
+        for (iterationNumber in iterationNumbers) {
+            for (pi1 in pi1Vec) {
+                row <- .getAggregatedDataByIterationNumber(rawData, iterationNumber, pi1)
+                if (!is.null(row)) {
+                    if (is.null(data)) {
+                        data <- row
+                    } else {
+                        data <- rbind(data, row)
+                    }
+                }
+            }
+        }
+    } else {
+        for (iterationNumber in iterationNumbers) {
+            row <- .getAggregatedDataByIterationNumber(rawData, iterationNumber)
+            if (!is.null(row)) {
+                if (is.null(data)) {
+                    data <- row
+                } else {
+                    data <- rbind(data, row)
+                }
+            }
+        }
+    }
+    return(data)
+}
+
+#'
+#' @title
+#' Get Simulation Raw Data for Survival
+#'
+#' @description
+#' Returns the raw survival data which was generated for simulation.
+#'
+#' @param x A \code{\link{SimulationResults}} object created by \code{\link[=getSimulationSurvival]{getSimulationSurvival()}}.
+#' @param aggregate Logical. If \code{TRUE} the raw data will be aggregated similar to
+#'        the result of \code{\link[=getData]{getData()}}, default is \code{FALSE}.
+#'
+#' @details
+#' This function works only if \code{\link[=getSimulationSurvival]{getSimulationSurvival()}} was called with a \cr
+#' \code{maxNumberOfRawDatasetsPerStage} > 0 (default is \code{0}).
+#'
+#' This function can be used to get the simulated raw data from a simulation results
+#' object obtained by \code{\link[=getSimulationSurvival]{getSimulationSurvival()}}. 
+#' Note that \code{\link[=getSimulationSurvival]{getSimulationSurvival()}}
+#' must called before with \code{maxNumberOfRawDatasetsPerStage} > 0.
+#' The data frame contains the following columns:
+#' \enumerate{
+#'   \item \code{iterationNumber}: The number of the simulation iteration.
+#'   \item \code{stopStage}: The stage of stopping.
+#'   \item \code{subjectId}: The subject id (increasing number 1, 2, 3, ...)
+#'   \item \code{accrualTime}: The accrual time, i.e., the time when the subject entered the trial.
+#'   \item \code{treatmentGroup}: The treatment group number (1 or 2).
+#'   \item \code{survivalTime}: The survival time of the subject.
+#'   \item \code{dropoutTime}: The dropout time of the subject (may be \code{NA}).
+#'   \item \code{observationTime}: The specific observation time.
+#'   \item \code{timeUnderObservation}: The time under observation is defined as follows:
+#' ```
+#' if (event == TRUE) {
+#'     timeUnderObservation <- survivalTime
+#' } else if (dropoutEvent == TRUE) {
+#'     timeUnderObservation <- dropoutTime
+#' } else {
+#'     timeUnderObservation <- observationTime - accrualTime
+#' }
+#' ```
+#'   \item \code{event}: \code{TRUE} if an event occurred; \code{FALSE} otherwise.
+#'   \item \code{dropoutEvent}: \code{TRUE} if an dropout event occurred; \code{FALSE} otherwise.
+#' }
+#'
+#' @template return_dataframe
+#'
+#' @examples
+#' \dontrun{
+#' results <- getSimulationSurvival(
+#'     pi1 = seq(0.3, 0.6, 0.1), pi2 = 0.3, eventTime = 12,
+#'     accrualTime = 24, plannedEvents = 40, maxNumberOfSubjects = 200,
+#'     maxNumberOfIterations = 50, maxNumberOfRawDatasetsPerStage = 5
+#' )
+#' rawData <- getRawData(results)
+#' head(rawData)
+#' dim(rawData)
+#' }
+#'
+#' @export
+#'
+getRawData <- function(x, aggregate = FALSE) {
+    if (!inherits(x, "SimulationResultsSurvival")) {
+        stop(
+            C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
+            "'x' must be a 'SimulationResultsSurvival' object; use getSimulationSurvival() to create one"
+        )
+    }
+    
+    rawData <- x$.rawData
+    if (is.null(rawData) || ncol(rawData) == 0 || nrow(rawData) == 0) {
+        stop(
+            C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
+            "simulation results contain no raw data; ",
+            "choose a 'maxNumberOfRawDatasetsPerStage' > 0, e.g., ",
+            "getSimulationSurvival(..., maxNumberOfRawDatasetsPerStage = 1)"
+        )
+    }
+    
+    if (!aggregate) {
+        return(rawData)
+    }
+    
+    return(.getAggregatedData(rawData))
+}
